@@ -161,8 +161,6 @@ void KstApp::initActions() {
                               this, SLOT(slotFileNewWindow()),
                               actionCollection(),"file_new_window");
 
-
-
   KStdAction::openNew(this, SLOT(slotFileNew()), actionCollection());
   KStdAction::open(   this, SLOT(slotFileOpen()), actionCollection());
   KStdAction::save(   this, SLOT(slotFileSave()), actionCollection());
@@ -194,17 +192,15 @@ void KstApp::initActions() {
   PauseAction = new KToggleAction(i18n("P&ause"),"player_pause",0,
                                   actionCollection(), "pause_action");
   PauseAction->setToolTip(i18n("Pause"));
-  PauseAction->setWhatsThis(
-    i18n("Pause: When paused, new data will not be read"));
+  PauseAction->setWhatsThis(i18n("When paused, new data will not be read."));
 
   /************/
   TiedZoomAction = new KAction(i18n("&Tied Zoom"),"kst_zoomtie",0,
                                view, SLOT(toggleTiedZoom()),
                                actionCollection(), "zoomtie_action");
   TiedZoomAction->setToolTip(i18n("Toggle tied zoom"));
-  TiedZoomAction->setWhatsThis(
-    i18n("Tied Zoom: Apply zoom actions to all plots\n"
-         "(not just the active one)"));
+  TiedZoomAction->setWhatsThis( i18n("Apply zoom actions to all plots\n"
+                                     "(not just the active one)."));
 
   /************/
   XYZoomAction = new KRadioAction(i18n("XY Mouse &Zoom"), "kst_zoomxy",0,
@@ -247,7 +243,7 @@ void KstApp::initActions() {
 
   TextAction->setToolTip(i18n("Label Editor"));
 
-  TextAction->setWhatsThis(i18n("Use the mouse to create and edit labels.\n"));
+  TextAction->setWhatsThis(i18n("Use the mouse to create and edit labels."));
 
   /************/
   PlotDialogAction = new KAction(i18n("Edit &Plots"), "kst_editplots", 0,
@@ -301,7 +297,7 @@ void KstApp::initActions() {
                                        actionCollection(),
                                        "changefiledialog_action");
   ChangeFileDialogAction->setWhatsThis(i18n("Bring up a dialog box\n"
-                                            "to change input files\n"));
+                                            "to change input files."));
 
   /************/
   ChangeNptsDialogAction = new KAction(i18n("Change Data Sample &Ranges"),
@@ -310,7 +306,7 @@ void KstApp::initActions() {
                                        actionCollection(),
                                        "changenptsdialog_action");
   ChangeNptsDialogAction->setWhatsThis(i18n("Bring up a dialog box\n"
-                                            "to change data sample ranges\n"));
+                                            "to change data sample ranges."));
 
   /************/
   QuickCurvesDialogAction = new KAction(i18n("Quickly Create New Curve"),
@@ -332,15 +328,14 @@ void KstApp::initActions() {
                                           "and put it in a plot."));
 
   /************/
-  GraphFileDialogAction = new
-                          KAction(i18n("Export to Graphics File..."),
+  GraphFileDialogAction = new KAction(i18n("Export to Graphics File..."),
                                   "kst_graphfile", 0,
                                   this, SLOT(showGraphFileDialog()),
                                   actionCollection(),
                                   "graphfiledialog_action");
   GraphFileDialogAction->setWhatsThis(i18n("Bring up a dialog box\n"
                                            "to export the plot as a\n"
-                                           "graphics file\n"));
+                                           "graphics file."));
 
   /************/
   _vectorSaveAction = new KAction(i18n("Save Vectors to Disk..."),
@@ -349,7 +344,7 @@ void KstApp::initActions() {
                                   actionCollection(),
                                   "vectorsavedialog_action");
   _vectorSaveAction->setWhatsThis(i18n("Bring up a dialog box\n"
-                                       "to save vectors to text files.\n"));
+                                       "to save vectors to text files."));
 
   /************/
   SamplesDownAction = new KAction(i18n("&Back 1 Screen"),
@@ -359,8 +354,8 @@ void KstApp::initActions() {
                                   actionCollection(),
                                   "samplesdown_action");
   //SamplesDownAction->setToolTip(i18n("Back"));
-  SamplesDownAction->setWhatsThis(i18n("Back: reduce starting frame by\n"
-    "current number of frames"));
+  SamplesDownAction->setWhatsThis(i18n("Reduce the starting frame by\n"
+                                       "the current number of frames."));
 
   /************/
   SamplesUpAction = new KAction(i18n("&Advance 1 Screen"),
@@ -371,8 +366,8 @@ void KstApp::initActions() {
                                 "samplesup_action");
 
   //SamplesUpAction->setToolTip(i18n("Advance"));
-  SamplesUpAction->setWhatsThis(i18n("Advance: increase starting frame by\n"
-    "current number of frames"));
+  SamplesUpAction->setWhatsThis(i18n("Increase the starting frame by\n"
+                                     "the current number of frames."));
 
   /************/
   SamplesFromEndAction = new KAction(i18n("Read From &End"),
@@ -382,13 +377,19 @@ void KstApp::initActions() {
                                      actionCollection(),
                                      "samplesend_action");
   SamplesFromEndAction->setToolTip(i18n("Read from end"));
-  SamplesFromEndAction->setToolTip(i18n("Read current data from end of file"));
+  SamplesFromEndAction->setWhatsThis(i18n("Read current data from end of file."));
 
   /************/
   PluginManagerAction = new KAction(i18n("&Plugins"), 0, 0,
                                  this, SLOT(showPluginManager()),
                                  actionCollection(), "pluginmanager_action");
 
+  DataMode = new KToggleAction(i18n("DataMode"), 0, 0,
+                                 this, SLOT(toggleDataMode()),
+                                 actionCollection(), "datamode_action");
+
+  _reloadAction = new KAction(i18n("Reload"), "reload", Key_F5, this, SLOT(reload()),
+                              actionCollection(), "reload");
   createGUI();
 }
 
@@ -413,13 +414,13 @@ void KstApp::togglePaused() {
 
 KstMouseModeType KstApp::getMouseZoomRadio() {
   if (XZoomAction->isChecked()) {
-    return (X_ZOOMBOX);
+    return X_ZOOMBOX;
   } else if (YZoomAction->isChecked()) {
-    return (Y_ZOOMBOX);
+    return Y_ZOOMBOX;
   } else if (TextAction->isChecked()) {
-    return (LABEL_TOOL);
+    return LABEL_TOOL;
   } else {
-    return (XY_ZOOMBOX);
+    return XY_ZOOMBOX;
   }
 }
 
@@ -432,9 +433,9 @@ void KstApp::initStatusBar() {
   statusBar()->setItemAlignment(KST_STATUSBAR_FRAME, AlignLeft | AlignVCenter);
   statusBar()->changeItem(i18n("Frame: 0"), KST_STATUSBAR_FRAME);
 
-  statusBar()->insertFixedItem("(000000000, 000000000)",
-                               KST_STATUSBAR_DATA, true);
   statusBar()->insertItem(i18n("Almost Ready"), KST_STATUSBAR_STATUS);
+  _dataBar = new QLabel("(00000000, 00000000)", statusBar());
+  statusBar()->addWidget(_dataBar, 0, true);
 
   statusBar()->show();
   slotUpdateStatusMsg(i18n("Ready"));
@@ -462,10 +463,11 @@ void KstApp::addRecentFile(const KURL &url) {
   recent->addURL(url);
 }
 
-void KstApp::openDocumentFile(const QString& in_filename,
+bool KstApp::openDocumentFile(const QString& in_filename,
 			      const QString& o_file, int o_n, int o_f, int o_s, bool o_ave) {
   KURL url;
   QFileInfo finfo(in_filename);
+  bool rc = false;
 
   url.setPath(in_filename);
   slotUpdateStatusMsg(i18n("Opening file..."));
@@ -477,9 +479,11 @@ void KstApp::openDocumentFile(const QString& in_filename,
     } else {
       addRecentFile(url);
     }
+    rc = true;
   }
   slotUpdateStatusMsg(i18n("Ready"));
   view->show();
+  return rc;
 }
 
 
@@ -701,7 +705,11 @@ void KstApp::slotUpdateFrameMsg(int frame) {
 }
 
 void KstApp::slotUpdateDataMsg(const QString &msg) {
-  statusBar()->changeItem(msg, KST_STATUSBAR_DATA);
+  _dataBar->setText(msg);
+}
+
+void KstApp::toggleDataMode() {
+  view->setDataMode(DataMode->isChecked());
 }
 
 /** Update everything */
@@ -778,6 +786,7 @@ void KstApp::samplesEnd() {
   setPaused(false);
 }
 
+
 void KstApp::updateDialogs() {
   KstVectorDialogI::globalInstance()->update();
   KstPluginDialogI::globalInstance()->update();
@@ -795,6 +804,7 @@ void KstApp::updateDialogs() {
   view->update();
 }
 
+
 #include "pluginmanager.h"
 
 void KstApp::showPluginManager() {
@@ -805,6 +815,7 @@ void KstApp::showPluginManager() {
   KstPluginDialogI::globalInstance()->updatePluginList();
 }
 
+
 void KstApp::registerDocChange() {
   doc->update();
   doc->setModified();
@@ -812,5 +823,16 @@ void KstApp::registerDocChange() {
 }
 
 
+void KstApp::reload() {
+  for (KstVectorList::Iterator i = KST::vectorList.begin(); i != KST::vectorList
+      .end(); ++i) {
+    KstRVector *r = dynamic_cast<KstRVector*>((*i).data());
+    if (r) {
+      r->reload();
+    }
+  }
+}
+
+
 #include "kst.moc"
 // vim: ts=2 sw=2 et
