@@ -46,11 +46,15 @@ public:
 
   virtual double maxX()    const { return MaxX; }
   virtual double minX()    const { return MinX; }
+  virtual double ns_maxX()    const { return MaxX; }
+  virtual double ns_minX()    const { return MinX; }
   virtual double minPosX() const { return MinPosX; }
   virtual double meanX()   const { return MeanX; }
   virtual double midX()    const { return (MaxX+MinX)*0.5; }
   virtual double maxY()    const { return MaxY; }
   virtual double minY()    const { return MinY; }
+  virtual double ns_maxY()    const { return MaxY; }
+  virtual double ns_minY()    const { return MinY; }
   virtual double minPosY() const { return MinPosY; }
   virtual double meanY()   const { return MeanY; }
   virtual double midY()    const { return (MaxY+MinY)*0.5; }
