@@ -17,8 +17,8 @@
 
 #include "kstdatacollection.h"
 
-  /** The list of files which are being looked at. */
-  KstFileList KST::fileList;
+  /** The list of data sources (files) */
+  KstDataSourceList KST::dataSourceList;
 
   /** The list of vectors that are being read */
   KstVectorList KST::vectorList;
