@@ -18,15 +18,16 @@
 #ifndef KSTDATACOLLECTION_H
 #define KSTDATACOLLECTION_H
 
-#include <qfile.h>
-#include "kstfile.h"
 #include "kstvector.h"
 #include "kstscalar.h"
 #include "kstdataobject.h"
+#include "kstdatasource.h"
+
+class QFile;
 
 namespace KST {
-  /** The list of files which are being looked at. */
-  extern KstFileList fileList;
+  /** The list of data sources (files) */
+  extern KstDataSourceList dataSourceList;
 
   /** The list of vectors that are being read */
   extern KstVectorList vectorList;
