@@ -99,7 +99,7 @@ void KstObjectItem::update(bool recursive) {
         setText(3, QString::number(x->sampleCount()));
         setText(4, i18n("%3: %4 [%1..%2]").arg(x->reqStartFrame())
             .arg(x->reqStartFrame() + x->reqNumFrames())
-            .arg(x->getFilename())
+            .arg(x->filename())
             .arg(x->getField()));
         _removable = x->getUsage() == 3;
         break;
@@ -159,11 +159,21 @@ void KstObjectItem::update(bool recursive) {
   }
 }
 
-void KstObjectItem::activate() {
+void KstObjectItem::updateButtons() {
   _dm->Edit->setEnabled(RTTI_OBJ_VECTOR != _rtti);
   _dm->Delete->setEnabled(_removable);
 }
 
+void KstObjectItem::reload() {
+  KstVectorList::Iterator v = KST::vectorList.findTag(_name);
+  if (v != KST::vectorList.end()) {
+    KstRVector *r = dynamic_cast<KstRVector*>((*v).data());
+    if (r) {
+      r->reload();
+    }
+  }
+}
+
 void KstObjectItem::makeCurve() {
   KstCurveDialogI::globalInstance()->show_New();
   KstCurveDialogI::globalInstance()->_yVector->setSelection(_name);
@@ -197,6 +207,8 @@ KstDataManagerI::KstDataManagerI(KstDoc *in_doc, QWidget* parent, const char* na
     connect(Purge, SIGNAL(clicked()), doc, SLOT(purge()));
     connect(DataView, SIGNAL(doubleClicked(QListViewItem *)),
             this, SLOT(edit_I()));
+    connect(DataView, SIGNAL(currentChanged(QListViewItem *)),
+            this, SLOT(currentChanged(QListViewItem *)));
 
     connect(NewCurve, SIGNAL(clicked()),
             KstCurveDialogI::globalInstance(), SLOT(show_New()));
@@ -220,13 +232,17 @@ KstDataManagerI::~KstDataManagerI() {
 
 
 void KstDataManagerI::show_I() {
-  update();
   show();
   raise();
+  update();
 }
 
 
 void KstDataManagerI::update() {
+if (!isShown()) {
+  return;
+}
+
 QPtrStack<QListViewItem> trash;
 
   // Garbage collect first
@@ -281,8 +297,12 @@ QPtrStack<QListViewItem> trash;
     }
   }
 
-  Edit->setEnabled(DataView->currentItem() != 0L);
-  Delete->setEnabled(DataView->currentItem() != 0L);
+  if (DataView->selectedItem()) {
+    static_cast<KstObjectItem*>(DataView->currentItem())->updateButtons();
+  } else {
+    Edit->setEnabled(false);
+    Delete->setEnabled(false);
+  }
 }
 
 
@@ -334,6 +354,7 @@ void KstDataManagerI::contextMenu(QListViewItem *i, const QPoint& p, int col) {
 
     if (koi->rtti() == RTTI_OBJ_DATA_VECTOR) {
       id = m->insertItem(i18n("&Make Curve..."), koi, SLOT(makeCurve()));
+      id = m->insertItem(i18n("&Reload"), koi, SLOT(reload()));
     } else if ((c = dynamic_cast<KstBaseCurve*>(koi->dataObject().data()))) {
       KPopupMenu *addMenu = new KPopupMenu(this);
       KPopupMenu *removeMenu = new KPopupMenu(this);
@@ -370,5 +391,10 @@ void KstDataManagerI::doUpdates() {
 }
 
 
+void KstDataManagerI::currentChanged(QListViewItem *i) {
+  KstObjectItem *koi = static_cast<KstObjectItem*>(i);
+  koi->updateButtons();
+}
+
 #include "kstdatamanager_i.moc"
 // vim: ts=2 sw=2 et
