@@ -44,6 +44,7 @@ public slots:
 private slots:
   void doUpdates();
   void contextMenu(QListViewItem *i, const QPoint& p, int c);
+  void currentChanged(QListViewItem *);
 
 private:
   KstDoc *doc;
@@ -65,14 +66,13 @@ class KstObjectItem : public QObject, public QListViewItem {
     const QString& tagName() const { return _name; }
     KstDataObjectPtr dataObject() { return *KST::dataObjectList.findTag(_name); }
     bool removable() const { return _removable; }
-
-  protected:
-    virtual void activate();
+    void updateButtons();
 
   public slots:
     void addToPlot(int);
     void removeFromPlot(int);
     void makeCurve();
+    void reload();
 
   signals:
     void updated();
