@@ -32,16 +32,16 @@ Q_UNUSED(e);
 
 KstDataObject::~KstDataObject() {
   // Remove our slave vectors and scalars
-  for (KstScalarList::Iterator it = _outputScalars.begin();
-                                it != _outputScalars.end();
-                                                       ++it) {
-    KST::scalarList.remove(*it);
+  for (KstScalarMap::Iterator it = _outputScalars.begin();
+                               it != _outputScalars.end();
+                                                      ++it) {
+    KST::scalarList.remove(it.data());
   }
 
-  for (KstVectorList::Iterator it = _outputVectors.begin();
-                                it != _outputVectors.end();
-                                                       ++it) {
-    KST::vectorList.remove(*it);
+  for (KstVectorMap::Iterator it = _outputVectors.begin();
+                               it != _outputVectors.end();
+                                                      ++it) {
+    KST::vectorList.remove(it.data());
   }
   //kdDebug() << "+++ DESTROYING DATA OBJECT: " << (void*)this << endl;
 }
@@ -59,25 +59,22 @@ Q_UNUSED(ts);
 }
 
 void KstDataObject::loadInputs() {
-  for (QStringList::Iterator i = _inputVectorLoadQueue.begin();
-                              i != _inputVectorLoadQueue.end();
-                                                           ++i) {
-    KstVectorList::Iterator it = KST::vectorList.findTag(*i);
+  QValueList<QPair<QString,QString> >::Iterator i;
+  for (i = _inputVectorLoadQueue.begin(); i != _inputVectorLoadQueue.end(); ++i) {
+    KstVectorList::Iterator it = KST::vectorList.findTag((*i).second);
     if (it != KST::vectorList.end()) {
-      _inputVectors.append(*it);
+      _inputVectors.insert((*i).first, *it);
     } else {
-      kdWarning() << "Unable to find required vector: " << *i << endl;
+      kdWarning() << "Unable to find required vector: " << (*i).second << endl;
     }
   }
 
-  for (QStringList::Iterator i = _inputScalarLoadQueue.begin();
-                              i != _inputScalarLoadQueue.end();
-                                                           ++i) {
-    KstScalarList::Iterator it = KST::scalarList.findTag(*i);
+  for (i = _inputScalarLoadQueue.begin(); i != _inputScalarLoadQueue.end(); ++i) {
+    KstScalarList::Iterator it = KST::scalarList.findTag((*i).second);
     if (it != KST::scalarList.end()) {
-      _inputScalars.append(*it);
+      _inputScalars.insert((*i).first, *it);
     } else {
-      kdWarning() << "Unable to find required scalar: " << *i << endl;
+      kdWarning() << "Unable to find required scalar: " << (*i).second << endl;
     }
   }
 
@@ -89,15 +86,15 @@ void KstDataObject::loadInputs() {
 int KstDataObject::getUsage() const {
 int rc = 0;
 
-  for (KstVectorList::ConstIterator i = _outputVectors.begin(); i != _outputVectors.end(); ++i) {
-    if ((*i).data()) {
-      rc += (*i)->getUsage() - 1;
+  for (KstVectorMap::ConstIterator i = _outputVectors.begin(); i != _outputVectors.end(); ++i) {
+    if (i.data().data()) {
+      rc += i.data()->getUsage() - 1;
     }
   }
 
-  for (KstScalarList::ConstIterator i = _outputScalars.begin(); i != _outputScalars.end(); ++i) {
-    if ((*i).data()) {
-      rc += (*i)->getUsage() - 1;
+  for (KstScalarMap::ConstIterator i = _outputScalars.begin(); i != _outputScalars.end(); ++i) {
+    if (i.data().data()) {
+      rc += i.data()->getUsage() - 1;
     }
   }
 
