@@ -147,7 +147,7 @@ bool KstDoc::newDocument() {
 bool KstDoc::openDocument(const KURL &url, const QString &o_file,
                           int o_n, int o_f, int o_s, bool o_ave) {
   // Temp variables
-  KstFilePtr file;
+  KstDataSourcePtr file;
   KstRVectorPtr vector;
 
   deleteContents();
@@ -199,15 +199,17 @@ bool KstDoc::openDocument(const KURL &url, const QString &o_file,
         setDelay(e.text().toInt());
       } else if (e.tagName() == "kstfile") {
         if (o_file == "|") {
-          file = new KstFile(e);
+          file = KstDataSource::loadSource(e);
         } else {
-          file = new KstFile(o_file);
+          file = KstDataSource::loadSource(o_file);
         }
-        if (file->numFrames() < 1) { // No data in file
-          kdWarning() << I18N_NOOP("No data in file: ") << file->fileName()
+        if (file && (!file->isValid() || file->frameCount() < 1)) {
+          kdWarning() << QString("No data in file: %1").arg(file->fileName())
                       << endl;
         }
-        KST::fileList.append(file);
+        if (file) {
+          KST::dataSourceList.append(file);
+        }
       } else if (e.tagName() == "vector") {
         vector = new KstRVector(e, o_file, o_n, o_f, o_s, o_ave);
         // Vectors are automatically added to the global list.
@@ -225,7 +227,7 @@ bool KstDoc::openDocument(const KURL &url, const QString &o_file,
         KstBaseCurveList l = kstObjectSubList<KstDataObject,KstBaseCurve>(KST::dataObjectList);
         KST::plotList.append(new KstPlot(e, l));
       } else {
-        kdWarning() << I18N_NOOP("unsupported element: ") << e.tagName() << endl;
+        kdWarning() << QString("unsupported element: %1").arg(e.tagName()) << endl;
       }
     }
     n = n.nextSibling();
@@ -275,9 +277,9 @@ bool KstDoc::saveDocument(const QString &filename) {
   ts << " <updateDelay>" << delay() << "</updateDelay>" << endl;
 
   // save files
-  for (i = 0; i < (int)KST::fileList.count(); i++) {
+  for (i = 0; i < (int)KST::dataSourceList.count(); i++) {
     ts << " <kstfile>" << endl;
-    KST::fileList[i]->save(ts);
+    KST::dataSourceList[i]->save(ts);
     ts << " </kstfile>" << endl;
   }
 
@@ -321,7 +323,7 @@ void KstDoc::deleteContents()
   KST::vectorList.clear();
 
   /* delete the files from the filelist */
-  KST::fileList.clear();
+  KST::dataSourceList.clear();
 }
 
 /*****************
@@ -355,8 +357,8 @@ KstObject::UpdateType KstDoc::update(bool force) {
   }
 
   // Update the files
-  for (i = 0; i < KST::fileList.count(); i++) {
-    KST::fileList[i]->update();
+  for (i = 0; i < KST::dataSourceList.count(); i++) {
+    KST::dataSourceList[i]->update();
   }
 
   kapp->processEvents();
@@ -416,20 +418,19 @@ KstObject::UpdateType KstDoc::update(bool force) {
 
 void KstDoc::samplesUp() {
   KstRVectorPtr V;
-  int i;
   int f0, n, skip;
   bool doSkip, doAve;
   int fileN;
 
   KstRVectorList rvl = kstObjectSubList<KstVector,KstRVector>(KST::vectorList);
-  for (i = 0; i < (int)rvl.count(); i++) {
+  for (int i = 0; i < (int)rvl.count(); i++) {
     V = rvl[i];
     f0 = V->reqStartFrame();
     n = V->reqNumFrames();
     skip = V->skip();
     doSkip = V->doSkip();
     doAve =  V->doAve();
-    fileN = V->getFileLength();
+    fileN = V->fileLength();
 
     if (f0 + n > fileN) {
       f0 = fileN - n;
@@ -447,13 +448,12 @@ void KstDoc::samplesUp() {
 
 void KstDoc::samplesDown() {
   KstRVectorPtr V;
-  int i;
   int f0, n, skip;
   bool doSkip, doAve;
   int fileN;
 
   KstRVectorList rvl = kstObjectSubList<KstVector,KstRVector>(KST::vectorList);
-  for (i = 0; i < (int)rvl.count(); i++) {
+  for (int i = 0; i < (int)rvl.count(); i++) {
     V = rvl[i];
     f0 = V->reqStartFrame();
     if (f0 == -1)
@@ -462,7 +462,7 @@ void KstDoc::samplesDown() {
     skip = V->skip();
     doSkip = V->doSkip();
     doAve =  V->doAve();
-    fileN = V->getFileLength();
+    fileN = V->fileLength();
 
     if (f0 - n < 0) {
       f0 = 0;
@@ -481,20 +481,19 @@ void KstDoc::samplesDown() {
 
 void KstDoc::samplesEnd() {
   KstRVectorPtr V;
-  int i;
   int f0, n, skip;
   bool doSkip, doAve;
   int fileN;
 
   KstRVectorList rvl = kstObjectSubList<KstVector,KstRVector>(KST::vectorList);
-  for (i = 0; i < (int)rvl.count(); i++) {
+  for (int i = 0; i < (int)rvl.count(); i++) {
     V = rvl[i];
     f0 = -1;
     n = V->numFrames();
     skip = V->skip();
     doSkip = V->doSkip();
     doAve =  V->doAve();
-    fileN = V->getFileLength();
+    fileN = V->fileLength();
 
     V->changeFrames(f0, n, skip, doSkip, doAve);
   }
@@ -587,7 +586,7 @@ static bool backupFile(const QString& qFilename, const QString& backupDir,
    QCString cFilename = QFile::encodeName(qFilename);
    const char *filename = cFilename.data();
 
-   int fd = open( filename, O_RDONLY);
+   int fd = open(filename, O_RDONLY);
    if (fd < 0)
       return false;
 
