@@ -74,6 +74,9 @@ void KstEqDialogI::show_New() {
   update(-2);
   show();
   raise();
+  if (!KST::vectorList.isEmpty()) {
+    UseExistingVector->setChecked(true);
+  }
 }
 
 void KstEqDialogI::show_I(const QString &field) {
@@ -217,7 +220,7 @@ void KstEqDialogI::new_I() {
   } else {
     n = N->value();
     if (n < 2) {
-      KMessageBox::sorry(0L, i18n("The equation must be evaluated at more than 1 point.  Increase Num Samples."));
+      KMessageBox::sorry(0L, i18n("The equation must be evaluated at more than 1 point.  Increase the number of samples."));
       return;
     }
     x0 = XMin->text().toDouble(&ok);
@@ -361,7 +364,6 @@ void KstEqDialogI::delete_I() {
     return;
 
   KST::dataObjectList.removeTag(tag);
-  // FIXME: don't allow this if the equation is in use by a curve
   emit modified();
 }
 
