@@ -27,6 +27,8 @@
 #include <klocale.h>
 #include <kdebug.h>
 
+#include <qstylesheet.h>
+
 #include "kstdoc.h"
 #include "kstdatacollection.h"
 #include "kstequationcurve.h"
@@ -165,6 +167,7 @@ bool KstEquationCurve::isValid() const {
   return IsValid;
 }
 
+// FIXME: Optimize me, especially map lookups.
 KstObject::UpdateType KstEquationCurve::update(int update_counter) {
   bool force = false;
 
@@ -201,6 +204,7 @@ KstObject::UpdateType KstEquationCurve::update(int update_counter) {
   return UPDATE;
 }
 
+// FIXME: Optimize me, especially map lookups.
 void KstEquationCurve::getPoint(int i, double &x, double &y) {
   x = _inputVectors[XVECTOR]->interpolate(i, NS);
   y = _outputVectors[OUTVECTOR]->value()[i];
@@ -208,15 +212,15 @@ void KstEquationCurve::getPoint(int i, double &x, double &y) {
 
 void KstEquationCurve::save(QTextStream &ts) {
   ts << " <equation>" << endl;
-  ts << "  <tag>" << _tag << "</tag>" << endl;
-  ts << "  <equation>" << Equation << "</equation>" << endl;
+  ts << "  <tag>" << QStyleSheet::escape(_tag) << "</tag>" << endl;
+  ts << "  <equation>" << QStyleSheet::escape(Equation) << "</equation>" << endl;
   if (_staticX) {
     ts << "  <x0>" << QString::number(_inputVectors[XVECTOR]->min()) << "</x0>" << endl;
     ts << "  <x1>" << QString::number(_inputVectors[XVECTOR]->max()) << "</x1>" << endl;
     ts << "  <ns>" << QString::number(_inputVectors[XVECTOR]->sampleCount()) << "</ns>" << endl;
-    ts << "  <xvtag>" << _inputVectors[XVECTOR]->tagName() << "</xvtag>" << endl;
+    ts << "  <xvtag>" << QStyleSheet::escape(_inputVectors[XVECTOR]->tagName()) << "</xvtag>" << endl;
   } else {
-    ts << "  <xvector>" << _inputVectors[XVECTOR]->tagName() << "</xvector>" << endl;
+    ts << "  <xvector>" << QStyleSheet::escape(_inputVectors[XVECTOR]->tagName()) << "</xvector>" << endl;
     if (DoInterp) {
       ts << "  <interpolate/>" << endl;
     }
@@ -288,7 +292,7 @@ bool KstEquationCurve::slaveVectorsUsed() const {
 void KstEquationCurve::preProcess() {
 
   char TempString[1024];
-  char ts[100];
+  char ts[1020];
   int i,j,Prev;
   int i_t;
   unsigned i_v;
@@ -331,15 +335,20 @@ void KstEquationCurve::preProcess() {
     } else if (TempString[i]==' ') {
       i++;
     } else if (TempString[i]=='[') {
-      for (i_t = i; (TempString[i_t]!='\0') && (TempString[i_t]!=']'); i_t++)
-        ;
+      int i_brace = 1;
+      for (i_t = i+1; (TempString[i_t]!='\0') && (i_brace>0); i_t++) {
+        if (TempString[i_t]=='[')
+          i_brace++;
+        if (TempString[i_t]==']')
+          i_brace--;
+      }
+      i_t--;
 
-      if (i_t - i - 1>98)
-        i_t = i + 98;
+      if (i_t - i - 1>1019)
+        i_t = i + 1019;
 
       strncpy(ts,TempString+i+1, i_t - i - 1);
       ts[i_t-i-1] = '\0';
-
       replaced = false;
       for (i_v = 0; i_v < KST::vectorList.count(); i_v++) {
         if (KST::vectorList[i_v]->tagName() == ts) {
@@ -405,11 +414,13 @@ bool KstEquationCurve::FillRPNQ() {
 	  vstack.Pop(Tmp2);
 	  vstack.Pop(Tmp1);
 	  opstack.Pop(Tmp3);
+          // FIXME: buffer overflow
 	  sprintf(Tmp,"%s;%s;%s;",Tmp1,Tmp2,Tmp3);
 	  vstack.LPush(Tmp);
 	} else {
 	  vstack.Pop(Tmp1);
 	  opstack.Pop(Tmp2);
+          // FIXME: buffer overflow
 	  sprintf(Tmp,"%s;%s;",Tmp1,Tmp2);
 	  vstack.LPush(Tmp);
 	}
@@ -428,11 +439,13 @@ bool KstEquationCurve::FillRPNQ() {
 	    vstack.Pop(Tmp2);
 	    vstack.Pop(Tmp1);
 	    opstack.Pop(Tmp3);
+          // FIXME: buffer overflow
 	    sprintf(Tmp,"%s;%s;%s;",Tmp1,Tmp2,Tmp3);
 	    vstack.LPush(Tmp);
 	  } else {
 	    vstack.Pop(Tmp1);
 	    opstack.Pop(Tmp2);
+          // FIXME: buffer overflow
 	    sprintf(Tmp,"%s;%s;",Tmp1,Tmp2);
 	    vstack.LPush(Tmp);
 	  }
@@ -459,11 +472,13 @@ bool KstEquationCurve::FillRPNQ() {
       vstack.Pop(Tmp2);
       vstack.Pop(Tmp1);
       opstack.Pop(Tmp3);
+      // FIXME: buffer overflow
       sprintf(Tmp,"%s;%s;%s;",Tmp1,Tmp2,Tmp3);
       vstack.LPush(Tmp);
     } else {
       vstack.Pop(Tmp1);
       opstack.Pop(Tmp2);
+      // FIXME: buffer overflow
       sprintf(Tmp,"%s;%s;",Tmp1,Tmp2);
       vstack.LPush(Tmp);
     }
@@ -490,6 +505,7 @@ bool KstEquationCurve::FillRPNQ() {
 /*                     	Fill Y: Evaluates the equation                 	*/
 /*                                                                     	*/
 /************************************************************************/
+// FIXME: Optimize me
 bool KstEquationCurve::FillY(bool force) {
   int i;
   unsigned r = 0;
@@ -509,7 +525,7 @@ bool KstEquationCurve::FillY(bool force) {
       }
     }
     if (_inputVectors[XVECTOR]->sampleCount() > 0) {
-      Interp = ns / _inputVectors[XVECTOR]->sampleCount();
+      Interp = (ns+1) / (_inputVectors[XVECTOR]->sampleCount());
     } else { // avoid divide by zero
       Interp = 1;
     }
@@ -519,7 +535,7 @@ bool KstEquationCurve::FillY(bool force) {
 
   if (NS != _inputVectors[XVECTOR]->sampleCount() || Interp != 1 ||
       _inputVectors[XVECTOR]->numShift() != _inputVectors[XVECTOR]->numNew() || ScalarsUsed.count()) {
-    NS = _inputVectors[XVECTOR]->sampleCount()*Interp;
+    NS = _inputVectors[XVECTOR]->sampleCount()*Interp-1;
 
     KstVectorPtr yv = _outputVectors[OUTVECTOR];
     yv->resize(NS);
