@@ -74,6 +74,18 @@ k_dcop:
 
   virtual const QString& createCurve(const QString& name, const QString& xVector, const QString& yVector, const QString& xErrorVector, const QString& yErrorVector, const QColor& color) = 0; 
   virtual const QString& createCurve(const QString& name, const QString& xVector, const QString& yVector, const QString& xErrorVector, const QString& yErrorVector) = 0; 
+
+  virtual void reloadVectors() = 0;
+  virtual void reloadVector(const QString& vector) = 0;
+
+  virtual const QString& loadVector(const QString& file, const QString& field) = 0;
+
+  virtual const QString& fileName() = 0;
+  virtual bool save() = 0;
+  virtual bool saveAs(const QString& fileName) = 0;
+  virtual void newFile() = 0;
+  virtual bool open(const QString& fileName) = 0;
+
 };
 
 #endif
