@@ -29,6 +29,9 @@
 #include <kprinter.h>
 #include <assert.h>
 
+#include <qfile.h>
+#include <qfileinfo.h>
+
 
 KstIfaceImpl::KstIfaceImpl(KstDoc *doc, KstApp *app)
 : DCOPObject("KstIface"), _doc(doc), _app(app) {
@@ -342,6 +345,7 @@ QString n = name;
   _doc->update();
   _doc->setModified();
   _doc->updateDialogs();
+  KST::plotList.arrangePlots(KST::plotList.getPlotCols());
 
 return p->tagName();
 }
@@ -462,4 +466,95 @@ bool KstIfaceImpl::printPostScript(const QString& url) {
 return true; // FIXME: eventually return an error code
 }
 
+
+void KstIfaceImpl::reloadVectors() {
+  _app->reload();
+}
+
+
+void KstIfaceImpl::reloadVector(const QString& vector) {
+  KstVectorList::Iterator v = KST::vectorList.findTag(vector);
+  if (v != KST::vectorList.end()) {
+    KstRVector *r = dynamic_cast<KstRVector*>((*v).data());
+    if (r) {
+      r->reload();
+    }
+  }
+}
+
+
+const QString& KstIfaceImpl::loadVector(const QString& file, const QString& field) {
+  KstDataSourcePtr src;
+  /* generate or find the kstfile */
+  KstDataSourceList::Iterator it = KST::dataSourceList.findFileName(file);
+
+  if (it == KST::dataSourceList.end()) {
+    src = KstDataSource::loadSource(file);
+    if (!src || !src->isValid()) {
+      return QString::null;
+    }
+    if (src->frameCount() < 1) {
+      return QString::null;
+    }
+    KST::dataSourceList.append(src);
+  } else {
+    src = *it;
+  }
+
+  QString vname = "V" + QString::number(KST::vectorList.count() + 1);
+
+  while (KST::vectorTagNameNotUnique(vname, false)) {
+    vname = "V" + QString::number(KST::vectorList.count() + 1);
+  }
+
+  KstVectorPtr p = new KstRVector(src, field, vname, 0, -1, 0, false, false);
+
+  if (p) {
+    _doc->update();
+    _doc->setModified();
+    _doc->updateDialogs();
+    return p->tagName();
+  }
+
+  return QString::null;
+}
+
+
+const QString& KstIfaceImpl::fileName() {
+  return _doc->getAbsFilePath();
+}
+
+
+bool KstIfaceImpl::save() {
+  if (_doc->getTitle() != "Untitled") {
+    return _doc->saveDocument(_doc->getAbsFilePath());
+  }
+  return false;
+}
+
+
+bool KstIfaceImpl::saveAs(const QString& fileName) {
+  bool rc = _doc->saveDocument(fileName);
+  if (rc) {
+    QFileInfo saveAsInfo(fileName);
+    _doc->setTitle(saveAsInfo.fileName());
+    _doc->setAbsFilePath(saveAsInfo.absFilePath());
+
+    _app->setCaption(kapp->caption() + ": " + _doc->getTitle());
+  }
+  return rc;
+}
+
+
+void KstIfaceImpl::newFile() {
+  _doc->newDocument();
+}
+
+
+bool KstIfaceImpl::open(const QString& fileName) {
+  return _app->openDocumentFile(fileName);
+}
+
+
+
 // vim: ts=2 sw=2 et
