@@ -70,6 +70,18 @@ public:
   virtual const QString& createCurve(const QString& name, const QString& xVector, const QString& yVector, const QString& xErrorVector, const QString& yErrorVector);
   virtual const QString& createCurve(const QString& name, const QString& xVector, const QString& yVector, const QString& xErrorVector, const QString& yErrorVector, const QColor& color);
 
+  virtual void reloadVectors();
+  virtual void reloadVector(const QString& vector);
+
+  virtual const QString& loadVector(const QString& file, const QString& field);
+
+  virtual const QString& fileName();
+  virtual bool save();
+  virtual bool saveAs(const QString& fileName);
+  virtual void newFile();
+  virtual bool open(const QString& fileName);
+
+
 private:
   KstDoc *_doc;
   KstApp *_app;
