@@ -48,16 +48,23 @@ KstLabel::KstLabel(const QString &in_text,
 
   doScalarReplacement = true;
   IsSample = is_sample;
+  Width = -1; // invalidate the width
 }
 
 KstLabel::~KstLabel(){
 }
 
 void KstLabel::setText(const QString &in_text) {
+  if (Text != in_text) {
+    Width = -1; // invalidate the width
+  }
   Text = in_text;
 }
 
 void KstLabel::setRotation(float in_rotation) {
+  if (Rotation != in_rotation) {
+    Width = -1; // invalidate the width
+  }
   Rotation = in_rotation;
 }
 
@@ -67,12 +74,17 @@ void KstLabel::setRelPosition(float in_X, float in_Y) {
 }
 
 void KstLabel::setJustification(KstJustifyType in_j) {
+  if (Justify != in_j) {
+    Width = -1; // invalidate the width
+  }
   Justify = in_j;
 }
 
 /** Return the width of the label */
 int KstLabel::width(QPainter &p) {
-  draw(p, 0, 0, false); // Do a dummy draw to evaluate the width
+  // FIXME: this is still expensive.
+  if (Width < 0)
+    draw(p, 0, 0, false); // Do a dummy draw to evaluate the width
   return int(Width);
 }
 
@@ -88,6 +100,7 @@ int KstLabel::ascent(QPainter &p) {
   return Ascent;
 }
 
+// FIXME: expensive - cache it?
 int KstLabel::lineSpacing(QPainter &p) {
   int LineSpacing = 0;
   QFont TextFont(FontName, fontSize(p), QFont::Normal, false);
@@ -124,6 +137,9 @@ void KstLabel::draw(QPainter &p, int px, int py, bool doDraw) {
   const int N_GREEK = 44;
   QString processedText;
 
+  // FIXME: This parsing is really slow.  We should cache the parse results.
+  //        We should also use a faster parsing algorithm.
+
   static const GreekCharType GC[] = {{"\\Alpha", "A"}, {"\\alpha", "a"},
                                      {"\\Beta", "B"}, {"\\beta", "b"},
                                      {"\\Chi", "C"}, {"\\chi", "c"},
@@ -232,11 +248,11 @@ void KstLabel::draw(QPainter &p, int px, int py, bool doDraw) {
       if (i_fp < 29) {
         i_fp++;
         fP[i_fp].locked = false;
-        fP[i_fp].size = fP[i_fp-1].size-1;
-        fP[i_fp].dy = fP[i_fp-1].dy + -p.fontMetrics().ascent()*0.4;
+        fP[i_fp].size = fP[i_fp-1].size - 1;
+        fP[i_fp].dy = fP[i_fp-1].dy - p.fontMetrics().ascent()*0.4;
         fP[i_fp].x = x;
         if (p.fontMetrics().rightBearing(C.at(0)) < 0) {
-          x -= 2.0*p.fontMetrics().rightBearing(C.at(0));
+          x -= 2.0 * p.fontMetrics().rightBearing(C.at(0));
         }
       }
     } else if (processedText[i] == '_') { /* Subscript */
@@ -264,39 +280,46 @@ void KstLabel::draw(QPainter &p, int px, int py, bool doDraw) {
       SymbolFont.setPointSize(s);
 
       is_greek = false;
+      QString subProcessedText = processedText.mid(i);
       for (i_g = 0; i_g < N_GREEK; i_g++) {
-        if (GC[i_g].label == processedText.mid(i, GC[i_g].label.length())) {
+        if (subProcessedText.startsWith(GC[i_g].label)) {
           is_greek = true;
           C = GC[i_g].c;
           i += GC[i_g].label.length()-1;
           if (processedText[i+1] == ' ')
             i++;
-          i_g = N_GREEK;
+          break;
         }
       }
+
       if (is_greek) {
         p.setFont(SymbolFont);
       } else {
         p.setFont(TextFont);
 
-        if (processedText.mid(i,2) == "\\_") {
-          C = "_";
-          i++;
-        } else if (processedText.mid(i,2) == "\\^") {
-          C = "^";
-          i++;
-        } else if (processedText.mid(i,3) == "\\it") {
-          TextFont.setItalic(true);
-          i += 2;
-          if (processedText[i+1] == ' ')
+        if (processedText[i] == '\\') {
+          if (processedText[i+1] == '_') {
+            C = "_";
             i++;
-          C = QString::null;
-        } else if (processedText.mid(i,3) == "\\rm") {
-          TextFont.setItalic(false);
-          i += 2;
-          if (processedText[i+1] == ' ')
+          } else if (processedText[i+1] == '^') {
+            C = "^";
             i++;
-          C = QString::null;
+          } else if (processedText[i+1] == 'i' && processedText[i+2] == 't') {
+            TextFont.setItalic(true);
+            i += 2;
+            if (processedText[i+1] == ' ')
+              i++;
+            C = QString::null;
+          } else if (processedText[i+1] == 'r' && processedText[i+2] == 'm') {
+            TextFont.setItalic(false);
+            i += 2;
+            if (processedText[i+1] == ' ')
+              i++;
+            C = QString::null;
+          } else {
+            C = processedText[i];
+            p.setFont(TextFont);
+          }
         } else {
           C = processedText[i];
           p.setFont(TextFont);
@@ -379,10 +402,12 @@ void KstLabel::read(QDomElement &e) {
 
 
 void KstLabel::setSize(int in_size) {
+  Width = -1; // invalidate the width
   Size = in_size;
 }
 
 void KstLabel::setFontName(const QString &in_fontName) {
+  Width = -1; // invalidate the width
   FontName = in_fontName;
 }
 
@@ -426,6 +451,9 @@ QString KstLabel::fontName() {
 }
 
 void KstLabel::setDoScalarReplacement(bool in_do) {
+  if (in_do != doScalarReplacement) {
+    Width = -1; // invalidate the width
+  }
   doScalarReplacement = in_do;
 }
 
