@@ -23,6 +23,9 @@
 #include <qstringlist.h>
 #include <qobject.h>
 
+class KstObjectPrivate;
+
+// BINARY COMPATIBILITY IS NOT YET GUARANTEED
 class KstObject : public KShared, public QObject {
 public:
   KstObject();
@@ -31,12 +34,12 @@ public:
   typedef enum {NO_CHANGE=0, READ, UPDATE} UpdateType;
 
   virtual UpdateType update(int updateCounter = -1) = 0;
-  virtual const QString& tagName() const { return _tag; }
-  virtual void setTagName(const QString& newTag) { _tag = newTag; }
+  virtual const QString& tagName() const;
+  virtual void setTagName(const QString& newTag);
 
-  virtual QString tagLabel() const { return QString("[%1]").arg(_tag); }
+  virtual QString tagLabel() const;
   // Returns count - 2 to account for "this" and the list pointer
-  virtual int getUsage() const { return _KShared_count() - 1; }
+  virtual int getUsage() const;
 
   // Returns true if update has already been done
   virtual bool checkUpdateCounter(int update_counter);
@@ -44,8 +47,18 @@ public:
   int operator==(const QString&) const;
 
 protected:
+  virtual void virtual_hook(int id, void *data);
   QString _tag;
   int _lastUpdateCounter;
+
+private:
+  KstObjectPrivate *d;
+
+  // NOTE: In order to preserve binary compatibility with plugins, you must
+  //       not add, remove, or change member variables or virtual functions.
+  //       You must also not remove or change non-virtual functions.  You can
+  //       add new variables to the KstObjectPrivate pointer if you need
+  //       them.  You can simulate virtual functions with the virtual_hook().
 };
 
 
