@@ -464,6 +464,34 @@ void KstPlot::updateScale() {
           }
         }
         break;
+      case NOSPIKE:  // set scale so all of all curves fits
+        if (Curves.isEmpty()) {
+          XMin = 0;
+          XMax = 1.0;
+        } else {
+          if (XLog) {
+            XMin = Curves[0]->minPosX();
+          } else {
+            XMin = Curves[0]->ns_minX();
+          }
+          XMax = Curves[0]->ns_maxX();
+          for (unsigned i = 1; i < Curves.count(); i++) {
+            if (XLog) {
+              if (XMin > Curves[i]->minPosX())
+                XMin = Curves[i]->minPosX();
+            } else {
+              if (XMin > Curves[i]->ns_minX())
+                XMin = Curves[i]->ns_minX();
+            }
+            if (XMax < Curves[i]->ns_maxX())
+              XMax = Curves[i]->ns_maxX();
+          }
+          if (XMax <= XMin) {  // if curves had no variation in them
+            XMin -= 0.1;
+            XMax = XMin + 0.2;
+          }
+        }
+        break;
       case AC: // keep range const, but set mid to mid of all curves
         if (XMax<=XMin) { // make sure that range is legal
           XMin =0; XMax = 1;
@@ -560,6 +588,43 @@ void KstPlot::updateScale() {
           }
         }
         break;
+      case NOSPIKE:  // set scale so all of all curves fits
+        if (Curves.isEmpty()) {
+          YMin = 0;
+          YMax = 1.0;
+        } else {
+          bool isPsd=false;
+
+          if (YLog) {
+            YMin = Curves[0]->minPosY();
+          } else {
+            YMin = Curves[0]->ns_minY();
+          }
+          YMax = Curves[0]->ns_maxY();
+          if (Curves[0]->type() == KST_PSDCURVE)
+            isPsd=true;
+          for (unsigned i = 1; i < Curves.count(); i++) {
+            if (YLog) {
+              if (YMin > Curves[i]->minPosY())
+                YMin = Curves[i]->minPosY();
+            } else {
+              if (YMin > Curves[i]->ns_minY())
+                YMin = Curves[i]->ns_minY();
+            }
+            if (YMax < Curves[i]->ns_maxY())
+              YMax = Curves[i]->ns_maxY();
+            if (Curves[0]->type() == KST_PSDCURVE)
+              isPsd = true;
+          }
+          if (YMax <= YMin) {  // if curves had no variation in them
+            YMin -= 0.1;
+            YMax = YMin + 0.2;
+          }
+          if (isPsd && (!YLog)) { /* psd plots should default to 0min */
+            YMin = 0;
+          }
+        }
+        break;
       case AC: // keep range const, but set mid to mean of all curves
         if (YMax <= YMin) { // make sure that range is legal
           YMin = 0;
@@ -641,7 +706,7 @@ inline void SafeD2I(double &dx, int &x) {
 
 static void genAxisTikLabel(char *label, double z, bool isLog) {
   if (isLog) {
-    if ((z>-4) && (z<4)) {
+    if (z > -4 && z < 4) {
       sprintf(label, "%.9g", pow(10,z));
     } else {
       sprintf(label, "10^{%.0f}", z);
@@ -734,21 +799,26 @@ void KstPlot::setBorders(double &xleft_bdr_px, double &xright_bdr_px,
   ytop_bdr_px = 1.3*TopLabel->lineSpacing(p);
   ybot_bdr_px = 1.3*XLabel->lineSpacing(p) + TickLabel->ascent(p);
 
+  // FIXME: loop is not needed for this calculation
   for (i = 0; i*YTick + Yorg < YMax; i++)
      /* do nothing */;
   i--;
+
   genAxisTikLabel(TmpStr,i*YTick+Yorg, YLog);
   TickLabel->setJustification(RxCy);
   TickLabel->setText(TmpStr);
   xleft_bdr_px = TickLabel->width(p);
+
   /* now check min label */
+  // FIXME: loop is not needed for this calculation
   for (i = -1; i*YTick + Yorg > YMin; i--)
      /* do nothing */;
   i++;
   genAxisTikLabel(TmpStr,i*YTick+Yorg, YLog);
   TickLabel->setText(TmpStr);
   i = TickLabel->width(p);
-  if (i> xleft_bdr_px) xleft_bdr_px = i;
+  if (i > xleft_bdr_px)
+    xleft_bdr_px = i;
   xleft_bdr_px+= 1.5*YLabel->lineSpacing(p)+5;
 
   xright_bdr_px = x_px/30;
@@ -1070,6 +1140,9 @@ void KstPlot::paint(QPainter &p, double in_xleft_bdr_px) {
 	/* Read i_pt = 0 */
         nopoint = false;
 	c->getPoint(i0, rX, rY);
+// Optimize - isnan seems expensive, at least in gcc debug mode
+//            cachegrind backs this up.
+#define isnan(x) (x != x)
         if (isnan(rX))
           nopoint = true;
         if (isnan(rY))
@@ -1092,9 +1165,9 @@ void KstPlot::paint(QPainter &p, double in_xleft_bdr_px) {
 	X1 = m_X*rX + b_X;
 	Y1 = m_Y*rY + b_Y;
 
-	last_x1=X1;
+	last_x1 = X1;
         last_x1i = (int)X1;
-	last_y1=Y1;
+	last_y1 = Y1;
 
 	for (i_pt = i0+1; i_pt < iN; i_pt++) {
 
@@ -1106,6 +1179,7 @@ void KstPlot::paint(QPainter &p, double in_xleft_bdr_px) {
           nopoint = false;
           c->getPoint(i_pt, rX, rY);
           while ((isnan(rX) || isnan(rY)) && i_pt < iN) {
+#undef isnan
             nopoint = true;
             i_pt++;
             c->getPoint(i_pt, rX, rY);
