@@ -30,7 +30,7 @@
  *@author cbn
  */
 
-typedef enum {AUTO, AC, FIXED, AUTOUP} KstScaleModeType;
+typedef enum {AUTO, AC, FIXED, AUTOUP, NOSPIKE} KstScaleModeType;
 
 struct KstPlotScale {
   double xmin;
@@ -42,6 +42,8 @@ struct KstPlotScale {
 };
 
 // FIXME: make KSharedPtr asap!! - could be causing bugs already
+// DONT fixme - grumpy barth says ksharedptrs are evil - they just mask
+// bugs (very effectivly).
 class KstPlot {
 public:
 
