@@ -115,6 +115,8 @@ KstPlotDialogI::KstPlotDialogI(KstDoc *in_doc, QWidget* parent,
             this, SLOT(setScalarDestTopLabel()));
 
     SampleLabel = new KstLabel("\0", CxCy, 0.0, 0.0, 0.0, true);
+    QFontDatabase qfd;
+    FontComboBox->setFonts(qfd.families());
 }
 
 KstPlotDialogI::~KstPlotDialogI() {
@@ -134,7 +136,10 @@ void KstPlotDialogI::update(int new_index) {
   KstPlot *plot;
   KstBaseCurvePtr curve;
   double xmin, ymin, xmax, ymax;
-  QFontDatabase qfd;
+
+  if (!isShown()) {
+    return;
+  }
 
   KstBaseCurveList curves = kstObjectSubList<KstDataObject, KstBaseCurve>(KST::dataObjectList);
   /* Fill the scalar combo */
@@ -144,9 +149,9 @@ void KstPlotDialogI::update(int new_index) {
   }
 
   /* Fill the Select combo, and set it to the right item */
-  if (new_index>=0) {
+  if (new_index >= 0) {
     index = new_index;
-  } else if (Select->count()>0) {
+  } else if (Select->count() > 0) {
     index = Select->currentItem();
   } else {
     index = Select->count()-1;
@@ -214,7 +219,12 @@ void KstPlotDialogI::update(int new_index) {
       XFixed->setChecked(true);
     } else if (plot->getXScaleMode() == AUTOUP) {
       XAutoUp->setChecked(true);
+    } else if (plot->getXScaleMode() == NOSPIKE) {
+      XNoSpikes->setChecked(true);
+    } else {
+      XAuto->setChecked(true);
     }
+
     if (plot->getYScaleMode() == AUTO) {
       YAuto->setChecked(true);
     } else if (plot->getYScaleMode() == AC) {
@@ -223,6 +233,10 @@ void KstPlotDialogI::update(int new_index) {
       YFixed->setChecked(true);
     } else if (plot->getYScaleMode() == AUTOUP) {
       YAutoUp->setChecked(true);
+    } else if (plot->getYScaleMode() == NOSPIKE) {
+      YNoSpikes->setChecked(true);
+    } else {
+      YAuto->setChecked(true);
     }
 
     NumberFontSize->setValue(plot->TickLabel->size());
@@ -236,9 +250,6 @@ void KstPlotDialogI::update(int new_index) {
     TopLabelText->setText(plot->TopLabel->text());
     TopLabelFontSize->setValue(plot->TopLabel->size());
 
-    FontComboBox->clear();
-
-    FontComboBox->setFonts(qfd.families());
     FontComboBox->setCurrentFont(plot->TopLabel->fontName());
 
     updateSampXLabel();
@@ -307,6 +318,8 @@ void KstPlotDialogI::applyLimits(KstPlot *plot) {
     plot->setXScaleMode(AUTOUP);
   } else if (XAuto->isChecked()) {
     plot->setXScaleMode(AUTO);
+  } else if (XNoSpikes->isChecked()) {
+    plot->setXScaleMode(NOSPIKE);
   } else {
     kdDebug() << "Bug in kst: no x scale type checked (?!!)" << endl;
   }
@@ -322,6 +335,8 @@ void KstPlotDialogI::applyLimits(KstPlot *plot) {
     plot->setYScaleMode(AUTOUP);
   } else if (YAuto->isChecked()) {
     plot->setYScaleMode(AUTO);
+  } else if (YNoSpikes->isChecked()) {
+    plot->setYScaleMode(NOSPIKE);
   } else {
     kdDebug() << "Bug in kst: no y scale type checked (?!!)" << endl;
   }
