@@ -27,24 +27,23 @@
 #include <stdlib.h>
 
 
-static void countScalarsAndVectors(const QValueList<Plugin::Data::IOValue>& table, unsigned& scalars, unsigned& vectors)
-{
+static void countScalarsAndVectors(const QValueList<Plugin::Data::IOValue>& table, unsigned& scalars, unsigned& vectors) {
   scalars = 0;
   vectors = 0;
 
   for (QValueList<Plugin::Data::IOValue>::ConstIterator it = table.begin(); it != table.end(); ++it) {
-        switch ((*it)._type) {
-          case Plugin::Data::IOValue::FloatType:
-            scalars++;
-            break;
-          case Plugin::Data::IOValue::TableType:
-            if ((*it)._subType == Plugin::Data::IOValue::FloatSubType) {
-              vectors++;
-            }
-            break;
-          default:
-            break;
+    switch ((*it)._type) {
+      case Plugin::Data::IOValue::FloatType:
+        scalars++;
+        break;
+      case Plugin::Data::IOValue::TableType:
+        if ((*it)._subType == Plugin::Data::IOValue::FloatSubType) {
+          vectors++;
         }
+        break;
+      default:
+        break;
+    }
   }
 }
 
@@ -60,6 +59,7 @@ KstPlugin::KstPlugin(QDomElement &e) : KstDataObject(e) {
   commonConstructor();
 
   QDomNode n = e.firstChild();
+
   while(!n.isNull()) {
     QDomElement e = n.toElement();
     if(!e.isNull()) {
@@ -68,13 +68,13 @@ KstPlugin::KstPlugin(QDomElement &e) : KstDataObject(e) {
       } else if (e.tagName() == "name") {
         pluginName = e.text();
       } else if (e.tagName() == "ivector") {
-        _inputVectorLoadQueue.append(e.text());
+        _inputVectorLoadQueue.append(qMakePair(e.attribute("name"), e.text()));
       } else if (e.tagName() == "iscalar") {
-        _inputScalarLoadQueue.append(e.text());
+        _inputScalarLoadQueue.append(qMakePair(e.attribute("name"), e.text()));
       } else if (e.tagName() == "ovector") {
-        _outputVectors.append(new KstVector(e.text()));
+        _outputVectors.insert(e.attribute("name"), new KstVector(e.text()));
       } else if (e.tagName() == "oscalar") {
-        _outputScalars.append(new KstScalar(e.text()));
+        _outputScalars.insert(e.attribute("name"), new KstScalar(e.text()));
       }
     }
     n = n.nextSibling();
@@ -86,26 +86,34 @@ KstPlugin::KstPlugin(QDomElement &e) : KstDataObject(e) {
     KMessageBox::sorry(0L, i18n("Unable to load plugin %1 for \"%2\".").arg(pluginName).arg(_tag));
   } else {
     countScalarsAndVectors(_plugin->data()._inputs, _inScalarCnt, _inArrayCnt);
-    countScalarsAndVectors(_plugin->data()._outputs, _outScalarCnt, _outArrayCnt);
 
-    for (unsigned i = _outputVectors.count(); i < _outArrayCnt; i++) {
-      _outputVectors.append(new KstVector(tagName() + " unnamed vector"));
-    }
-
-    for (unsigned i = _outputScalars.count(); i < _outScalarCnt; i++) {
-      _outputScalars.append(new KstScalar(tagName() + " unnamed scalar"));
+    const QValueList<Plugin::Data::IOValue>& otable = _plugin->data()._outputs;
+    for (QValueList<Plugin::Data::IOValue>::ConstIterator it = otable.begin();
+                                                           it != otable.end();
+                                                                         ++it) {
+      if ((*it)._type == Plugin::Data::IOValue::TableType) {
+        _outArrayCnt++;
+        if (!_outputVectors.contains((*it)._name)) {
+          _outputVectors.insert((*it)._name, new KstVector(tagName() + " vector - " + (*it)._name));
+        }
+      } else if ((*it)._type == Plugin::Data::IOValue::FloatType) {
+        _outScalarCnt++;
+        if (!_outputScalars.contains((*it)._name)) {
+          _outputScalars.insert((*it)._name, new KstScalar(tagName() + " scalar - " + (*it)._name));
+        }
+      }
     }
   }
 }
 
 
 void KstPlugin::commonConstructor() {
-  _typeString = i18n("Plugin");
-  _plugin = 0L;
   _inScalarCnt = 0;
   _outScalarCnt = 0;
   _inArrayCnt = 0;
   _outArrayCnt = 0;
+  _typeString = i18n("Plugin");
+  _plugin = 0L;
   //kdDebug() << "Creating KSTPlugin: " << long(this) << endl;
 }
 
@@ -145,26 +153,51 @@ KstObject::UpdateType KstPlugin::update(int update_counter) {
     outScalars = new double[_outScalarCnt];
   }
 
-  for (unsigned i = 0; i < _inArrayCnt; i++) {
-    if (!_inputVectors[i].data()) {
-      kdWarning() << "Plugin [" << tagName() << "]: Input vector " << i << " is invalid.  Cannot continue." << endl;
-      return NO_CHANGE;
+#define CLEANUP() do {\
+  delete[] inVectors;\
+  delete[] outVectors;\
+  delete[] outArrayLens;\
+  delete[] inArrayLens;\
+  delete[] outScalars;\
+  delete[] inScalars;\
+  } while(0)
+
+
+  const QValueList<Plugin::Data::IOValue>& itable = _plugin->data()._inputs;
+  const QValueList<Plugin::Data::IOValue>& otable = _plugin->data()._outputs;
+  int itcnt = 0, vitcnt = 0;
+
+  // Populate the input scalars and vectors
+  for (QValueList<Plugin::Data::IOValue>::ConstIterator it = itable.begin();
+                                                         it != itable.end();
+                                                                        ++it) {
+    if ((*it)._type == Plugin::Data::IOValue::TableType) {
+      if (!_inputVectors.contains((*it)._name)) {
+        kdWarning() << "Plugin [" << tagName() << "]: Input vector " << (*it)._name << " not found.  Cannot continue." << endl;
+        CLEANUP();
+        return NO_CHANGE;
+      }
+      inVectors[vitcnt] = _inputVectors[(*it)._name]->value();
+      inArrayLens[vitcnt++] = _inputVectors[(*it)._name]->sampleCount();
+    } else if ((*it)._type == Plugin::Data::IOValue::FloatType) {
+      inScalars[itcnt++] = _inputScalars[(*it)._name]->value();
     }
-    inVectors[i] = _inputVectors[i]->value();
-    inArrayLens[i] = _inputVectors[i]->sampleCount();
   }
 
-  for (unsigned i = 0; i < _inScalarCnt; i++) {
-    inScalars[i] = _inputScalars[i]->value();
-  }
-
-  for (unsigned i = 0; i < _outArrayCnt; i++) {
-    if (!_outputVectors[i].data()) {
-      kdWarning() << "Plugin [" << tagName() << "]: Output vector " << i << " is invalid.  Cannot continue." << endl;
-      return NO_CHANGE;
+  vitcnt = 0;
+  // Populate the output vectors
+  for (QValueList<Plugin::Data::IOValue>::ConstIterator it = otable.begin();
+                                                         it != otable.end();
+                                                                        ++it) {
+    if ((*it)._type == Plugin::Data::IOValue::TableType) {
+      if (!_outputVectors.contains((*it)._name)) {
+        kdWarning() << "Plugin [" << tagName() << "]: Output vector " << (*it)._name << " not found.  Cannot continue." << endl;
+        CLEANUP();
+        return NO_CHANGE;
+      }
+      outVectors[vitcnt] = _outputVectors[(*it)._name]->value();
+      outArrayLens[vitcnt++] = _outputVectors[(*it)._name]->length();
     }
-    outVectors[i] = _outputVectors[i]->value();
-    outArrayLens[i] = 1;
   }
 
   int rc = _plugin->call(inVectors,  inArrayLens,  inScalars,
@@ -174,21 +207,22 @@ KstObject::UpdateType KstPlugin::update(int update_counter) {
     // Error
   }
 
-  for (unsigned i = 0; i < _outArrayCnt; i++) {
-    vectorRealloced(_outputVectors[i], outVectors[i], outArrayLens[i]);
+  itcnt = 0;
+  vitcnt = 0;
+  // Read back the output vectors and scalars
+  for (QValueList<Plugin::Data::IOValue>::ConstIterator it = otable.begin();
+                                                         it != otable.end();
+                                                                        ++it) {
+    if ((*it)._type == Plugin::Data::IOValue::TableType) {
+      vectorRealloced(_outputVectors[(*it)._name], outVectors[vitcnt], outArrayLens[vitcnt]);
+      vitcnt++;
+    } else if ((*it)._type == Plugin::Data::IOValue::FloatType) {
+      _outputScalars[(*it)._name]->setValue(outScalars[itcnt++]);
+    }
   }
 
-  for (unsigned i = 0; i < _outScalarCnt; i++) {
-    _outputScalars[i]->setValue(outScalars[i]);
-  }
-
-  delete[] inVectors;
-  delete[] outVectors;
-  delete[] outArrayLens;
-  delete[] inArrayLens;
-  delete[] outScalars;
-  delete[] inScalars;
-
+  CLEANUP();
+#undef CLEANUP
   return UPDATE;
 }
 
@@ -198,20 +232,24 @@ void KstPlugin::save(QTextStream &ts) {
     ts << " <plugin>" << endl;
     ts << "   <tag>" << _tag << "</tag>" << endl;
     ts << "   <name>" << _plugin->data()._name << "</name>" << endl;
-    for (unsigned i = 0; i < _inputVectors.count(); i++) {
-      ts << "   <ivector>" << _inputVectors[i]->tagName()
+    for (KstVectorMap::Iterator i = _inputVectors.begin(); i != _inputVectors.end(); ++i) {
+      ts << "   <ivector name=\"" << i.key() << "\">"
+         << i.data()->tagName()
          << "</ivector>" << endl;
     }
-    for (unsigned i = 0; i < _inputScalars.count(); i++) {
-      ts << "   <iscalar>" << _inputScalars[i]->tagName()
+    for (KstScalarMap::Iterator i = _inputScalars.begin(); i != _inputScalars.end(); ++i) {
+      ts << "   <iscalar name=\"" << i.key() << "\">"
+         << i.data()->tagName()
          << "</iscalar>" << endl;
     }
-    for (unsigned i = 0; i < _outputVectors.count(); i++) {
-      ts << "   <ovector>" << _outputVectors[i]->tagName()
+    for (KstVectorMap::Iterator i = _outputVectors.begin(); i != _outputVectors.end(); ++i) {
+      ts << "   <ovector name=\"" << i.key() << "\">"
+         << i.data()->tagName()
          << "</ovector>" << endl;
     }
-    for (unsigned i = 0; i < _outputScalars.count(); i++) {
-      ts << "   <oscalar>" << _outputScalars[i]->tagName()
+    for (KstScalarMap::Iterator i = _outputScalars.begin(); i != _outputScalars.end(); ++i) {
+      ts << "   <oscalar name=\"" << i.key() << "\">"
+         << i.data()->tagName()
          << "</oscalar>" << endl;
     }
     ts << " </plugin>" << endl;
@@ -271,10 +309,10 @@ bool KstPlugin::setPlugin(KSharedPtr<Plugin> plugin) {
                                                          it != otable.end();
                                                                         ++it) {
     if ((*it)._type == Plugin::Data::IOValue::TableType) {
-      _outputVectors.append(new KstVector);
+      _outputVectors.insert((*it)._name, new KstVector);
       _outArrayCnt++;
     } else if ((*it)._type == Plugin::Data::IOValue::FloatType) {
-      _outputScalars.append(new KstScalar);
+      _outputScalars.insert((*it)._name, new KstScalar);
       _outScalarCnt++;
     }
   }
