@@ -97,7 +97,6 @@ KstPSDCurve::KstPSDCurve(QDomElement &e)
 
   commonConstructor(in_tag, in_V, in_freq, in_len,
                     in_VUnits, in_RUnits, in_color);
-
 }
 
 void KstPSDCurve::commonConstructor(const QString &in_tag, KstVectorPtr in_V,
@@ -130,15 +129,17 @@ void KstPSDCurve::commonConstructor(const QString &in_tag, KstVectorPtr in_V,
   setAppodize(true);
 
   KstVectorPtr iv = new KstVector(_tag+"-freq", 2);
-  _outputVectors.insert(FVECTOR, iv);
+  _fVector = _outputVectors.insert(FVECTOR, iv);
 
   iv = new KstVector(_tag+"-sv", PSDLen);
-  _outputVectors.insert(SVECTOR, iv);
+  _sVector = _outputVectors.insert(SVECTOR, iv);
 
   update();
 }
 
 KstPSDCurve::~KstPSDCurve() {
+  _sVector = _outputVectors.end();
+  _fVector = _outputVectors.end();
   KST::vectorList.remove(_outputVectors[SVECTOR]);
   KST::vectorList.remove(_outputVectors[FVECTOR]);
 
@@ -164,7 +165,7 @@ void KstPSDCurve::GenW() {
 }
 
 inline double cabs(double r, double i) {
-  return (sqrt(r*r + i*i));
+  return sqrt(r*r + i*i);
 }
 
 KstObject::UpdateType KstPSDCurve::update(int update_counter) {
@@ -175,6 +176,7 @@ KstObject::UpdateType KstPSDCurve::update(int update_counter) {
   double mean;
   double y;
   bool force = false;
+  KstVectorPtr iv = _inputVectors[INVECTOR];
 
   double *psd;
 
@@ -184,20 +186,20 @@ KstObject::UpdateType KstPSDCurve::update(int update_counter) {
   if (update_counter <= 0) {
     force = true;
   } else {
-    _inputVectors[INVECTOR]->update(update_counter);
+    iv->update(update_counter);
   }
 
-  v_len = _inputVectors[INVECTOR]->sampleCount();
+  v_len = iv->sampleCount();
 
   n_subsets = v_len/PSDLen+1;
 
-  last_n_new += _inputVectors[INVECTOR]->numNew();
+  last_n_new += iv->numNew();
 
   if ((last_n_new < PSDLen/16) && (n_subsets - last_n_subsets < 1) && !force) {
     return NO_CHANGE;
   }
 
-  psd = _outputVectors[SVECTOR]->value();
+  psd = (*_sVector)->value();
 
   for (i_samp = 0; i_samp < PSDLen; i_samp++) {
     psd[i_samp] = 0;
@@ -214,7 +216,7 @@ KstObject::UpdateType KstPSDCurve::update(int update_counter) {
     for (i_samp = 0; i_samp < copyLen; i_samp++) {
       mean += (
         a[i_samp] =
-        _inputVectors[INVECTOR]->interpolate(i_samp + i_subset*PSDLen, v_len)
+        iv->interpolate(i_samp + i_subset*PSDLen, v_len)
         );
     }
     if (copyLen>1) mean/=(double)copyLen;
@@ -284,37 +286,37 @@ KstObject::UpdateType KstPSDCurve::update(int update_counter) {
   MinPosX = 1.0/double(NS) * MaxX;
   MeanX = MaxX/2.0;
 
-  double *f = _outputVectors[FVECTOR]->value();
+  double *f = (*_fVector)->value();
   f[0] = 0;
   f[1] = Freq/2.0;
 
-  _outputVectors[SVECTOR]->update(update_counter);
-  _outputVectors[FVECTOR]->update(update_counter);
+  (*_sVector)->update(update_counter);
+  (*_fVector)->update(update_counter);
 
   return UPDATE;
 }
 
 void KstPSDCurve::getPoint(int i, double &x, double &y) {
-  x = _outputVectors[FVECTOR]->interpolate(i, NS);
+  x = (*_fVector)->interpolate(i, NS);
 //xxxdouble(i)/double(NS) * MaxX;
-  y = _outputVectors[SVECTOR]->interpolate(i, NS);
+  y = (*_sVector)->interpolate(i, NS);
 }
 
 void KstPSDCurve::save(QTextStream &ts) {
-  ts << " <psd>\n";
-  ts << "  <tag>" << _tag << "</tag>\n";
-  ts << "  <vectag>" << _inputVectors[INVECTOR]->tagName() << "</vectag>\n";
+  ts << " <psd>" << endl;
+  ts << "  <tag>" << _tag << "</tag>" << endl;
+  ts << "  <vectag>" << _inputVectors[INVECTOR]->tagName() << "</vectag>" << endl;
 
-  ts << "  <color>" << Color.name() << "</color>\n";
-  ts << "  <hasLines>" << HasLines << "</hasLines>\n";
-  ts << "  <hasPoints>" << HasPoints << "</hasPoints>\n";
-  ts << "  <pointType>" << Point.getType() << "</pointType>\n";
+  ts << "  <color>" << Color.name() << "</color>" << endl;
+  ts << "  <hasLines>" << HasLines << "</hasLines>" << endl;
+  ts << "  <hasPoints>" << HasPoints << "</hasPoints>" << endl;
+  ts << "  <pointType>" << Point.getType() << "</pointType>" << endl;
 
-  ts << "  <sampRate>"  << Freq << "</sampRate>\n";
-  ts << "  <fftLen>" << Len << "</fftLen>\n";
-  ts << "  <VUnits>" << VUnits << "</VUnits>\n";
-  ts << "  <RUnits>" << RUnits << "</RUnits>\n";
-  ts << " </psd>\n";
+  ts << "  <sampRate>"  << Freq << "</sampRate>" << endl;
+  ts << "  <fftLen>" << Len << "</fftLen>" << endl;
+  ts << "  <VUnits>" << VUnits << "</VUnits>" << endl;
+  ts << "  <RUnits>" << RUnits << "</RUnits>" << endl;
+  ts << " </psd>" << endl;
 }
 
 double KstPSDCurve::getFreq() const {
@@ -334,14 +336,14 @@ int KstPSDCurve::getLen() const {
 }
 
 void KstPSDCurve::setLen(int in_len) {
-  if ((in_len>=4) && (in_len<=24)) {
+  if (in_len >= 4 && in_len <= 24) {
     Len = in_len;
   } else {
     Len = 10;
   }
 
   PSDLen = int(pow(2,Len-1));
-  _outputVectors[SVECTOR]->resize(PSDLen);
+  (*_sVector)->resize(PSDLen);
 
   ALen = PSDLen*2;
   delete[] a;
