@@ -23,6 +23,7 @@
 #include <qcheckbox.h>
 #include <qspinbox.h>
 #include <qlabel.h>
+#include <kdebug.h>
 #include <kfiledialog.h>
 #include <klocale.h>
 #include <kcolorbutton.h>
@@ -42,14 +43,14 @@ KstQuickCurvesDialogI::KstQuickCurvesDialogI(QWidget* parent,
 
     connect(ColorButton, SIGNAL(changed(const QColor &)),
             this, SLOT(drawCurveLine()));
-    connect(Apply, SIGNAL(clicked()),
-            this, SLOT(apply()));
-    connect(ApplyPlotCols, SIGNAL(clicked()),
-            this, SLOT(addPlot()));
+    connect(Apply, SIGNAL(clicked()), this, SLOT(apply()));
+    connect(ApplyPlotCols, SIGNAL(clicked()), this, SLOT(addPlot()));
 
     FileName->setMode(KFile::File | KFile::Directory | KFile::ExistingOnly
                       | KFile::LocalOnly);
 
+    connect(FileName, SIGNAL(textChanged(const QString&)), this, SLOT(updateCompletion()));
+
     _xaxisCompletion = XAxis->completionObject();
     XAxis->setAutoDeleteCompletionObject(true);
     _yaxisCompletion = YAxis->completionObject();
@@ -66,6 +67,32 @@ void KstQuickCurvesDialogI::showQuickCurvesDialog() {
 }
 
 
+void KstQuickCurvesDialogI::updateCompletion() {
+  /* put INDEX as a default in the X axis list */
+  XAxis->clear();
+  YAxis->clear();
+
+  /* update filename list and fill axes combo boxes */
+  KstDataSourcePtr ds = *KST::dataSourceList.findFileName(FileName->url());
+  if (!ds && FileName->url() != "stdin") {
+    ds = KstDataSource::loadSource(FileName->url());
+    if (ds) { // FIXME we should eventually make KstDataSource::loadFieldList()
+      KST::dataSourceList.append(ds);
+    }
+  }
+
+  if (ds) {
+    XAxis->insertStringList(ds->fieldList());
+    _xaxisCompletion->insertItems(ds->fieldList());
+    YAxis->insertStringList(ds->fieldList());
+    _yaxisCompletion->insertItems(ds->fieldList());
+  }
+
+  XAxis->setCurrentText("INDEX");
+  YAxis->setCurrentText(QString::null);
+}
+
+
 void KstQuickCurvesDialogI::update() {
   unsigned int i;
   int j;
@@ -73,22 +100,11 @@ void KstQuickCurvesDialogI::update() {
 
   KstVCurveList curves = kstObjectSubList<KstDataObject, KstVCurve>(KST::dataObjectList);
 
-  /* put INDEX as a default in the X axis list */
-  XAxis->clear();
-  YAxis->clear();
-
-  /* update filename list and fill axes combo boxes */
-  j = KST::fileList.count()-1;
+  j = KST::dataSourceList.count() - 1;
   if (j >= 0) {
-    FileName->setURL(KST::fileList[j]->fileName());
-    XAxis->insertStringList(KST::fileList[j]->fieldList());
-    _xaxisCompletion->insertItems(KST::fileList[j]->fieldList());
-    YAxis->insertStringList(KST::fileList[j]->fieldList());
-    _yaxisCompletion->insertItems(KST::fileList[j]->fieldList());
+    FileName->setURL(KST::dataSourceList[j]->fileName());
   }
-
-  XAxis->setCurrentText("INDEX");
-  YAxis->setCurrentText("");
+  updateCompletion();
 
   KstRVectorList rvl = kstObjectSubList<KstVector,KstRVector>(KST::vectorList);
   /* set the file range defaults to those of Vector 0 */
@@ -133,7 +149,7 @@ void KstQuickCurvesDialogI::drawCurveLine() {
 }
 
 bool KstQuickCurvesDialogI::apply(bool autolabel) {
-  KstFilePtr file;
+  KstDataSourcePtr file;
   KstRVectorPtr tv, vx, vy;
   KstVCurvePtr curve;
   KstPlot *plot;
@@ -147,15 +163,19 @@ bool KstQuickCurvesDialogI::apply(bool autolabel) {
 
   KstVCurveList curves = kstObjectSubList<KstDataObject, KstVCurve>(KST::dataObjectList);
   /* generate or find the kstfile */
-  KstFileList::Iterator it = KST::fileList.findFileName(FileName->url());
+  KstDataSourceList::Iterator it = KST::dataSourceList.findFileName(FileName->url());
 
-  if (it == KST::fileList.end()) {
-    file = new KstFile(FileName->url());
-    if (file->numFrames() < 1) { // No data in file
-      KMessageBox::sorry(0L, i18n("The requested file does not contain data."));
+  if (it == KST::dataSourceList.end()) {
+    file = KstDataSource::loadSource(FileName->url());
+    if (!file || !file->isValid()) {
+      KMessageBox::sorry(0L, i18n("The file could not be loaded."));
       return false;
     }
-    KST::fileList.append(file);
+    if (file->frameCount() < 1) {
+      KMessageBox::sorry(0L, i18n("The file does not contain data."));
+      return false;
+    }
+    KST::dataSourceList.append(file);
   } else {
     file = *it;
   }
@@ -166,7 +186,7 @@ bool KstQuickCurvesDialogI::apply(bool autolabel) {
   /* make sure there are no vectors with the current vectors props */
   for (i_v = 0; i_v < rvl.count(); i_v++) {
     tv = rvl[i_v];
-    if ((tv->getFilename() == FileName->url()) &&
+    if ((tv->filename() == FileName->url()) &&
         (tv->getField() == XAxis->currentText()) &&
         (tv->reqStartFrame() == F0->value()) &&
         (tv->reqNumFrames() == N->value()) &&
@@ -207,7 +227,7 @@ bool KstQuickCurvesDialogI::apply(bool autolabel) {
   /* make sure there are no vectors with the current vectors props */
   for (i_v = 0; i_v < rvl.count(); i_v++) {
     tv = rvl[i_v];
-    if ((tv->getFilename() == FileName->url()) &&
+    if ((tv->filename() == FileName->url()) &&
         (tv->getField() == YAxis->currentText()) &&
         (tv->reqStartFrame() == F0->value()) &&
         (tv->reqNumFrames() == N->value()) &&
@@ -245,12 +265,16 @@ bool KstQuickCurvesDialogI::apply(bool autolabel) {
 
   if (x_is_new) {
     if (!vx->isValid()) {
+      KST::vectorList.remove(vx.data());
+      KST::vectorList.remove(vy.data());
       KMessageBox::sorry(0L, i18n("The requested X vector is not in the file."));
       return false;
     }
   }
   if (y_is_new) {
     if (!vy->isValid()) {
+      KST::vectorList.remove(vx.data());
+      KST::vectorList.remove(vy.data());
       KMessageBox::sorry(0L, i18n("The requested Y vector is not in the file."));
       return false;
     }
@@ -287,10 +311,10 @@ bool KstQuickCurvesDialogI::apply(bool autolabel) {
 bool KstQuickCurvesDialogI::addPlot() {
   KstPlot *plot = KST::plotList.addPlot(QString::null, PlotCols->value());
   PlotList->insertItem(plot->tagName());
-  PlotList->setCurrentItem(PlotList->count()-1);
+  PlotList->setCurrentItem(PlotList->count() - 1);
 
   if (!apply(true)) {
-    PlotList->removeItem(PlotList->count()-1);
+    PlotList->removeItem(PlotList->count() - 1);
     KST::plotList.remove(plot);
     return false;
   }
