@@ -42,8 +42,8 @@ public slots:
 
   bool addPlot();
 private slots:
-  bool apply(bool autolabel);
-  void apply() { apply(false); }
+  bool apply(bool autolabel = false);
+  void updateCompletion();
 
 signals:
   /** signal that things have changed */
