@@ -43,11 +43,15 @@ public:
   /** Update the vector.  Return true if there was new data. */
   virtual UpdateType update(int updateCounter = -1);
 
+  KstScalar& operator=(double v);
+
 private:
   double _value;
 };
 
 typedef KSharedPtr<KstScalar> KstScalarPtr;
+typedef KstObjectList<KstScalarPtr> KstScalarList;
+typedef KstObjectMap<KstScalarPtr> KstScalarMap;
 
 #endif
 // vim: ts=2 sw=2 et
