@@ -144,6 +144,8 @@ KstObject::UpdateType KstVCurve::update(int update_counter) {
   MinX = VX->min();
   MeanX = VX->mean();
   MinPosX = VX->minPos();
+  _ns_maxx = VX->ns_max();
+  _ns_minx = VX->ns_min();
 
   if (MinPosX > MaxX) {
     MinPosX = 0;
@@ -153,6 +155,8 @@ KstObject::UpdateType KstVCurve::update(int update_counter) {
   MinY = VY->min();
   MeanY = VY->mean();
   MinPosY = VY->minPos();
+  _ns_maxy = VY->ns_max();
+  _ns_miny = VY->ns_min();
 
   if (MinPosY > MaxY) {
     MinPosY = 0;
