@@ -70,6 +70,11 @@ public:
 
   virtual bool xIsRising() const {return VX->isRising(); }
 
+  virtual double ns_maxX()    const { return _ns_maxx; }
+  virtual double ns_minX()    const { return _ns_minx; }
+  virtual double ns_maxY()    const { return _ns_maxy; }
+  virtual double ns_minY()    const { return _ns_miny; }
+
 protected:
   virtual void _showDialog();
 
@@ -81,6 +86,11 @@ private:
   KstVectorPtr VY;
   KstVectorPtr EX;
   KstVectorPtr EY;
+
+  double _ns_maxx;
+  double _ns_minx;
+  double _ns_maxy;
+  double _ns_miny;
 };
 
 typedef KSharedPtr<KstVCurve> KstVCurvePtr;
