@@ -18,6 +18,7 @@
 
 #include <kdebug.h>
 
+#include <iostream>
 #include <assert.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -37,6 +38,8 @@ double KST::NOPOINT = 0.0/0.0; // NaN
 
 #define INITSIZE 1
 
+// FIXME: optimize scalar access
+
 /** Create a vector */
 KstVector::KstVector(const QString& name, int size)
 : KstObject(), _nsum(0), _scalars(11) {
@@ -84,6 +87,8 @@ KstVector::~KstVector() {
 }
 
 
+// FIXME: optimize me - possible that floor() (especially) and isnan() are
+//        expensive here.
 /** Return v[i], i is sample number, interpolated to have ns_i total
     samples in vector */
 double KstVector::interpolate(int in_i, int ns_i) {
@@ -91,28 +96,36 @@ double KstVector::interpolate(int in_i, int ns_i) {
   int j;
 
   /** Limits checks - optional? **/
-  if (in_i<0)
+  if (in_i < 0)
     return _v[0];
 
-  if (in_i >= ns_i-1)
-    return _v[_size-1];
+  if (in_i >= ns_i - 1)
+    return _v[_size - 1];
 
   /** speedup check **/
   if (ns_i == _size) { /* no extrapolating or decimating needed */
     return _v[in_i];
   }
 
-  fj = in_i * double(_size-1) / double(ns_i-1); //scaled index
+  fj = in_i * double(_size - 1) / double(ns_i-1); //scaled index
 
   j = int(floor(fj));	       // index of sample one lower
 
-  if (isnan(_v[j+1]) || isnan(_v[j])) {
-    return KST::NOPOINT;
+  // This is optimized to avoid unnecessary isnan calls!
+  if (_v[j + 1] != _v[j + 1]) {
+    if (isnan(_v[j + 1])) {
+      return KST::NOPOINT;
+    }
+  }
+  if (_v[j] != _v[j]) {
+    if (isnan(_v[j])) {
+      return KST::NOPOINT;
+    }
   }
 
   fdj = fj - float(j);     // fdj is fraction between _v[j] and _v[j+1]
 
-  return _v[j+1]*fdj + _v[j]*(1.0 - fdj);
+  return _v[j + 1] * fdj + _v[j] * (1.0 - fdj);
 }
 
 
@@ -211,9 +224,12 @@ void KstVector::resize(int sz, bool reinit) {
 
 
 KstObject::UpdateType KstVector::update(int update_counter) {
-  int i;
+  int i, i0;
   double max, min, sum, sum2, minpos, v;
-  double last_v = -1.0E100;
+  double last_v;
+  double dv2=0.0, dv, no_spike_max_dv;
+
+  max = min = sum = sum2 = minpos = 0.0;
 
   if (KstObject::checkUpdateCounter(update_counter))
     return NO_CHANGE;
@@ -225,41 +241,88 @@ KstObject::UpdateType KstVector::update(int update_counter) {
     for (i = 0; i < _size && !finite(_v[i]); i++)
       /* Do Nothing */ ;
 
-    if (i>0)
-      _is_rising = false;
+    if (i==_size) {
+      _scalars["sum"]->setValue(sum);
+      _scalars["sumsquared"]->setValue(sum2);
+      _scalars["max"]->setValue(max);
+      _scalars["min"]->setValue(min);
+      _scalars["minpos"]->setValue(minpos);
+      _ns_max = _ns_min = 0;
 
-    max = min = sum = sum2 = _v[i];
-    if (_v[i]>0)
-      minpos = _v[i];
+      UpdateScalars();
+      return UPDATE;
+    }
+
+    i0 = i;
+
+    if (i0>0) {
+      _is_rising = false;
+    }
+
+    max = min = sum = sum2 = _v[i0];
+    if (_v[i0]>0)
+      minpos = _v[i0];
     else
       minpos = 1.0E300;
 
-    for (; i < _size; i++) {
+    last_v = _v[i0];
+    for (i=i0; i < _size; i++) {
       v = _v[i]; // get rid of redirections
 
       if (finite(v)) {
 
-        if (v<=last_v)
-          _is_rising = false;
+        dv = v - last_v;
+        dv2 += dv*dv;
+
+        if (v<=last_v) {
+          if (i!=i0) {
+            _is_rising = false;
+          }
+        }
         last_v = v;
 
         _nsum++;
         sum += v;
         sum2 += v*v;
 
-        if (v>max)
+        if (v > max) {
           max = v;
-        else {
-          if (v<min)
+        } else {
+          if (v < min) {
             min = v;
-          if (v<minpos)
-            if (v>0)
+          }
+          if (v < minpos && v > 0) {
               minpos = v;
+          }
         }
       } else {
         _is_rising = false;
       }
     }
+
+    no_spike_max_dv = 7.0*sqrt(dv2/double(_nsum));
+
+    _ns_max = _ns_min = last_v = _v[i0];
+
+    for (i = i0; i < _size; i++) {
+      v = _v[i]; // get rid of redirections
+      if (finite(v)) {
+        if (fabs(v - last_v) < no_spike_max_dv) {
+          if (v > _ns_max) {
+            _ns_max = v;
+          } else if (v < _ns_min) {
+            _ns_min = v;
+          }
+          last_v = v;
+        } else {
+          i += 20;
+          if (i < _size)
+            last_v = _v[i];
+          i++;
+        }
+      }
+    }
+
     _scalars["sum"]->setValue(sum);
     _scalars["sumsquared"]->setValue(sum2);
     _scalars["max"]->setValue(max);
