@@ -70,6 +70,12 @@ public:
   /** Return max value in Vector */
   double max() const;
 
+  /** Return SpikeInsensitive max value in vector **/
+  double ns_max() const {return _ns_max;}
+
+  /** Return SpikeInsensitive min value in vector **/
+  double ns_min() const {return _ns_min;}
+
   /** Return Mean value in Vector */
   double mean() const;
 
@@ -121,6 +127,10 @@ protected: // Protected attributes
   /** number of valid points */
   int _nsum;
 
+  /** variables for SpikeInsensitiveAutoscale **/
+  double _ns_max;
+  double _ns_min;
+
   /** Where the vector is held */
   double *_v;
 
