@@ -146,10 +146,9 @@ void KstVectorDialogI::update(int new_index) {
   /* fill the fields */
   Field->clear();
   _fieldCompletion->clear();
-  KstFilePtr tf;
-  KstFileList::Iterator it =
-    KST::fileList.findFileName(vector->getFilename());
-  if (it != KST::fileList.end()) {
+  KstDataSourcePtr tf;
+  KstDataSourceList::Iterator it = KST::dataSourceList.findFileName(vector->filename());
+  if (it != KST::dataSourceList.end()) {
     tf = *it;
     Field->insertStringList(tf->fieldList());
     _fieldCompletion->insertItems(tf->fieldList());
@@ -157,13 +156,13 @@ void KstVectorDialogI::update(int new_index) {
   }
 
   if (isNew) {
-    Field->setCurrentText("");
+    Field->setCurrentText(QString::null);
   } else {
     Field->setCurrentText(vector->getField());
   }
 
   /* select the proper file */
-  FileName->setURL(vector->getFilename());
+  FileName->setURL(vector->filename());
 
   /* fill the vector range entries */
   if (vector->countFromEOF()) {
@@ -209,16 +208,13 @@ void KstVectorDialogI::browseFile() {
 }
 
 void KstVectorDialogI::new_I() {
-  KstFilePtr file;
+  KstDataSourcePtr file;
   KstRVectorPtr vector;
-  int i_c;
-  QString tag_name;
-
   KstRVectorList vectorList = kstObjectSubList<KstVector,KstRVector>(KST::vectorList);
-  tag_name = Select->currentText();
+  QString tag_name = Select->currentText();
   tag_name.replace(i18n("<New_Vector>"), Field->currentText());
 
-  i_c = KST::vectorList.count() + 1;
+  int i_c = KST::vectorList.count() + 1;
   while (KST::dataTagNameNotUnique(tag_name, false)) {
     tag_name.sprintf("V%d-", i_c);
     tag_name += Field->currentText();
@@ -226,15 +222,19 @@ void KstVectorDialogI::new_I() {
   }
 
   /* if there is not an active KstFile, create one */
-  KstFileList::Iterator it = KST::fileList.findFileName(FileName->url());
+  KstDataSourceList::Iterator it = KST::dataSourceList.findFileName(FileName->url());
 
-  if (it == KST::fileList.end()) {
-    file = new KstFile(FileName->url());
-    if (file->numFrames() < 1) { // No data in file
-      KMessageBox::sorry(0L, i18n("The requested file does not contain data."));
+  if (it == KST::dataSourceList.end()) {
+    file = KstDataSource::loadSource(FileName->url());
+    if (!file || !file->isValid()) {
+      KMessageBox::sorry(0L, i18n("The file could not be loaded."));
       return;
     }
-    KST::fileList.append(file);
+    if (file->frameCount() < 1) {
+      KMessageBox::sorry(0L, i18n("The file does not contain data."));
+      return;
+    }
+    KST::dataSourceList.append(file);
   } else {
     file = *it;
   }
@@ -260,17 +260,17 @@ void KstVectorDialogI::new_I() {
 }
 
 void KstVectorDialogI::edit_I() {
-  int index;
-  KstFilePtr file;
+  KstDataSourcePtr file;
   KstRVectorPtr vector;
 
-  index = Select->currentItem();
-  KstRVectorList vectorList = kstObjectSubList<KstVector,KstRVector>(KST::vectorList);
+  int index = Select->currentItem();
   if (index < 0) {
     KMessageBox::sorry(0L, i18n("You need to select an active vector to edit."));
     return;
   }
 
+  KstRVectorList vectorList = kstObjectSubList<KstVector,KstRVector>(KST::vectorList);
+
   if (unsigned(index) >= vectorList.count()) {
     new_I();
   } else {
@@ -280,15 +280,19 @@ void KstVectorDialogI::edit_I() {
     }
 
     /* if there is not an active KstFile, create one */
-    KstFileList::Iterator it = KST::fileList.findFileName(FileName->url());
+    KstDataSourceList::Iterator it = KST::dataSourceList.findFileName(FileName->url());
 
-    if (it == KST::fileList.end()) {
-      file = new KstFile(FileName->url());
-      if (file->numFrames() < 1) { // No data in file
-	KMessageBox::sorry(0L, i18n("The requested file does not contain data."));
+    if (it == KST::dataSourceList.end()) {
+      file = KstDataSource::loadSource(FileName->url());
+      if (!file || !file->isValid()) {
+	KMessageBox::sorry(0L, i18n("The file could not be opened."));
 	return;
       }
-      KST::fileList.append(file);
+      if (file->frameCount() < 1) {
+	KMessageBox::sorry(0L, i18n("The file does not contain data."));
+	return;
+      }
+      KST::dataSourceList.append(file);
     } else {
       file = *it;
     }
