@@ -55,6 +55,7 @@ KstView::KstView(KstApp *parent, const char *name)
 
   first_time = true;
   _minMove = 3;
+  _dataMode = false;
 
   ZoomCurrentPlot = false;
   ZoomPlotNum = 0;
@@ -72,6 +73,8 @@ KstView::KstView(KstApp *parent, const char *name)
   _titleId = popupmenu->insertTitle(i18n("Plot"));
   popupmenu->insertItem(i18n("Z&oom"), submenu);
   submenu->insertItem(i18n("Zoom &Maximum"), this, SLOT(zoomMaxSlot()), Key_M);
+  submenu->insertItem(i18n("Zoom Max &Spike Insensivie"),
+                      this, SLOT(zoomSpikeInsensiveMaxSlot()), Key_S);
   submenu->insertItem(i18n("Zoom P&revious"), this, SLOT(zoomPrevSlot()), Key_R);
   submenu->insertItem(i18n("Y-Zoom AC Coupled"), this, SLOT(yzoomAcSlot()), Key_A);
   submenu->insertSeparator();
@@ -361,14 +364,72 @@ void KstView::resizeEvent(QResizeEvent *) {
 void KstView::update() {
   needrecreate = true;
   paintEvent(NULL);
+  updateMouse();
+}
+
+void KstView::updateMouse() {
+  int plot = MouseInfo->getPlotNum();
+  QString msg;
+  KstPlot* pPlot;
+
+  if (plot >= 0 && (pPlot = KST::plotList.at(plot))) {
+    QRect plot_rect = pPlot->GetPlotRegion();
+    QPoint pos = mapFromGlobal(QCursor::pos());
+
+    if (!plot_rect.contains(pos)) {
+      emit newDataMsg(QString::null);
+      return;
+    }
+
+    double xmin, ymin, xmax, ymax, xpos, ypos;
+    pPlot->getLScale(xmin, ymin, xmax, ymax);
+
+    xpos = (double)(pos.x() - plot_rect.left())/(double)plot_rect.width();
+    xpos = xpos * (xmax - xmin) + xmin;
+    if (pPlot->isXLog()) {
+      xpos = pow(10.0, xpos);
+    }
+
+    ypos = (double)(pos.y() - plot_rect.top())/(double)plot_rect.height();
+    ypos = ypos * (ymin - ymax) + ymax;
+
+    if (pPlot->isYLog()) {
+      ypos = pow(10.0, ypos);
+    }
+ 
+    if (_dataMode) {
+      double newypos = ypos;
+      KstBaseCurvePtr curve;
+      double delta = 9e99;
+
+      for (KstBaseCurveList::Iterator i = pPlot->Curves.begin(); i != pPlot->Curves.end(); ++i) {
+        double xpt = 0.0, ypt = 0.0;
+        if (pPlot->isXLog()) {
+          (*i)->getPoint((*i)->sampleCount() * xpos / ((*i)->maxX() - (*i)->minX()), xpt, ypt);
+        } else {
+          (*i)->getPoint(xpos, xpt, ypt);
+        }
+        if (fabs(ypos - ypt) < delta) {
+          delta = fabs(ypos - ypt);
+          newypos = ypt;
+          curve = *i;
+        }
+      }
+      if (curve.data()) {
+        msg = i18n("%3 (%1, %2)").arg(xpos).arg(newypos,0,'G').arg(curve->tagName());
+        emit newDataMsg(msg);
+        return;
+      }
+    }
+
+    msg = i18n("(%1, %2)").arg(xpos,0,'G').arg(ypos,0,'G');
+  }
+  emit newDataMsg(msg);
 }
 
 void KstView::mouseMoveEvent(QMouseEvent *e) {
   int x,y;
-  int i;
-  QString msg;
-  QRect plot_rect;
-  double xmin, xmax, ymin, ymax, xpos, ypos;
+  int i, i0, iN;
   bool in_plot = false;
   int i_label;
   int plot_num = MouseInfo->getPlotNum();
@@ -445,49 +506,46 @@ void KstView::mouseMoveEvent(QMouseEvent *e) {
     MouseInfo->setLastLocation(QPoint(x,y));
   }
 
-  // change the xy field
-  //emit newDataMsg(msg);
+  if (ZoomCurrentPlot) {
+    i0 = ZoomPlotNum;
+    iN = ZoomPlotNum+1;
+  } else {
+    i0 = 0;
+    iN = KST::plotList.count();
+  }
 
-  msg = QString::null;
-
-  for (i = 0; i < (int)KST::plotList.count(); i++) {
-    plot_rect = KST::plotList.at(i)->GetPlotRegion();
+  for (i = i0; i < iN; i++) {
+    QRect plot_rect = KST::plotList.at(i)->GetPlotRegion();
     if (plot_rect.contains(e->pos())) {
-      KST::plotList.at(i)->getLScale(xmin, ymin, xmax, ymax);
-      xpos = (double)(e->x() - plot_rect.left())/(double)plot_rect.width();
-      xpos = xpos * (xmax - xmin) + xmin;
-      ypos = (double)(e->y() - plot_rect.top())/(double)plot_rect.height();
-      ypos = ypos * (ymin-ymax) + ymax;
-
-      if (KST::plotList.at(i)->isXLog()) {
-        xpos = pow(10.0, xpos);
-      }
-
-      if (KST::plotList.at(i)->isYLog()) {
-        ypos = pow(10.0, ypos);
-      }
-
-      msg = i18n("(%1, %2)").arg(xpos,0,'G').arg(ypos,0,'G');
       if (MouseInfo->getMode() == INACTIVE) {
+        MouseInfo->setPlotNum(i);
         if (i != plot_num) {
-          MouseInfo->setPlotNum(i);
           updateTieBoxes(this);
         }
       } else if (MouseInfo->getMode() == LABEL_TOOL) {
         MouseInfo->setPlotNum(i);
       }
       in_plot = true;
+      break;
     }
   }
-  emit newDataMsg(msg);
+  updateMouse();
   MouseInfo->setCursor(in_plot, e);
 }
 
 void KstView::mousePressEvent(QMouseEvent *e) {
-  unsigned int i;
+  unsigned int i, i0, iN;
   QRect win_rect, plot_rect, tie_rect, plot_and_axis_rect;
   KstPlot *plot;
 
+  if (ZoomCurrentPlot) {
+    i0 = ZoomPlotNum;
+    iN = ZoomPlotNum+1;
+  } else {
+    i0 = 0;
+    iN = KST::plotList.count();
+  }
+
   /* Find where the mouse was to determine which mode to be in */
   /* which button */
   if (e->button() == Qt::LeftButton) {
@@ -495,7 +553,7 @@ void KstView::mousePressEvent(QMouseEvent *e) {
     _draggableLabel = MouseInfo->getLabelNum(e);
     _draggablePoint = e->pos();
     /* search through the plots */
-    for (i = 0; i < KST::plotList.count(); i++) {
+    for (i = i0; i < iN; i++) {
       plot = KST::plotList.at(i);
       win_rect = plot->GetWinRegion();
       plot_rect = plot->GetPlotRegion();
@@ -530,7 +588,7 @@ void KstView::mousePressEvent(QMouseEvent *e) {
       }
     }
   } else if (e->button() == Qt::RightButton) {
-    for (i = 0; i < KST::plotList.count(); i++) {
+    for (i = i0; i < iN; i++) {
       KstPlot *p = KST::plotList.at(i);
       win_rect = p->GetPlotRegion();
       if (win_rect.contains(e->pos())) {
@@ -569,7 +627,7 @@ void KstView::mousePressEvent(QMouseEvent *e) {
       }
     }
   } else if (e->button() == Qt::MidButton) {
-    for (i = 0; i < KST::plotList.count(); i++) {
+    for (i = i0; i < iN; i++) {
       win_rect = KST::plotList.at(i)->GetPlotRegion();
       if (win_rect.contains(e->pos())) {
         MouseInfo->setMode(INACTIVE);
@@ -771,6 +829,22 @@ void KstView::zoomMaxSlot() {
   update();
 }
 
+void KstView::zoomSpikeInsensiveMaxSlot() {
+  unsigned int count = KST::plotList.count();
+
+  for (unsigned i_plot = 0; i_plot < count; i_plot++) {
+    KstPlot *iplot = KST::plotList.at(i_plot);
+    if (i_plot == MouseInfo->getPlotNum() || iplot->isTied()) {
+      iplot->setXScaleMode(NOSPIKE);
+      iplot->setYScaleMode(NOSPIKE);
+      iplot->pushScale();
+    }
+  }
+  MouseInfo->setMode(INACTIVE);
+  needrecreate = true;
+  update();
+}
+
 void KstView::keyPressEvent(QKeyEvent *e) {
   MouseInfo->setCursor(true, e->stateAfter());
 
@@ -986,35 +1060,14 @@ void KstView::zoomPrevSlot() {
 }
 
 void KstView::upSlot() {
-  double xmin, xmax, ymin, ymax;
-  double new_ymin, new_ymax;
-  unsigned int count = KST::plotList.count();
-  KstPlot *plot, *iplot;
-
-  plot = KST::plotList.at(MouseInfo->getPlotNum());
-  plot->getLScale(xmin, ymin, xmax, ymax);
-
-  new_ymin = ymin + (ymax - ymin)*0.25;
-  new_ymax = ymax + (ymax - ymin)*0.25;
-
-  for (unsigned i_plot = 0; i_plot < count; i_plot++) {
-    iplot = KST::plotList.at(i_plot);
-    if (i_plot == MouseInfo->getPlotNum() || iplot->isTied()) {
-      iplot->getLScale(xmin, ymin, xmax, ymax);
-      new_ymin = ymin + (ymax - ymin)*0.25;
-      new_ymax = ymax + (ymax - ymin)*0.25;
-
-      iplot->setYScaleMode(FIXED);
-      iplot->setLYScale(new_ymin, new_ymax);
-      iplot->pushScale();
-    }
-  }
-  MouseInfo->setMode(INACTIVE);
-  needrecreate = true;
-  update();
+  moveVertical(true);
 }
 
 void KstView::downSlot() {
+  moveVertical(false);
+}
+
+void KstView::moveVertical(bool up) {
   double xmin, xmax, ymin, ymax;
   double new_ymin, new_ymax;
   unsigned int count = KST::plotList.count();
@@ -1023,8 +1076,13 @@ void KstView::downSlot() {
   plot = KST::plotList.at(MouseInfo->getPlotNum());
   plot->getLScale(xmin, ymin, xmax, ymax);
 
-  new_ymin = ymin - (ymax - ymin)*0.25;
-  new_ymax = ymax - (ymax - ymin)*0.25;
+  if (up) {
+    new_ymin = ymin + (ymax - ymin)*0.25;
+    new_ymax = ymax + (ymax - ymin)*0.25;
+  } else {
+    new_ymin = ymin - (ymax - ymin)*0.25;
+    new_ymax = ymax - (ymax - ymin)*0.25;
+  }
 
 
   for (unsigned i_plot = 0; i_plot < count; i_plot++) {
@@ -1032,8 +1090,13 @@ void KstView::downSlot() {
     if (i_plot == MouseInfo->getPlotNum() || iplot->isTied()) {
       if (ParentApp->getMouseZoomRadio() == X_ZOOMBOX) {
         iplot->getLScale(xmin, ymin, xmax, ymax);
-        new_ymin = ymin - (ymax - ymin)*0.25;
-        new_ymax = ymax - (ymax - ymin)*0.25;
+        if (up) {
+          new_ymin = ymin + (ymax - ymin)*0.25;
+          new_ymax = ymax + (ymax - ymin)*0.25;
+        } else {
+          new_ymin = ymin - (ymax - ymin)*0.25;
+          new_ymax = ymax - (ymax - ymin)*0.25;
+        }
       }
 
       iplot->setYScaleMode(FIXED);
@@ -1049,31 +1112,15 @@ void KstView::downSlot() {
 }
 
 void KstView::rightSlot() {
-  double xmin, xmax, ymin, ymax;
-  double new_xmin, new_xmax;
-  unsigned int count = KST::plotList.count();
-  KstPlot *plot, *iplot;
-
-  plot = KST::plotList.at(MouseInfo->getPlotNum());
-  plot->getLScale(xmin, ymin, xmax, ymax);
-
-  new_xmin = xmin + (xmax - xmin)*0.1;
-  new_xmax = xmax + (xmax - xmin)*0.1;
-
-  for (unsigned i_plot = 0; i_plot < count; i_plot++) {
-    iplot = KST::plotList.at(i_plot);
-    if (i_plot == MouseInfo->getPlotNum() || iplot->isTied()) {
-      iplot->setXScaleMode(FIXED);
-      iplot->setLXScale(new_xmin, new_xmax);
-      iplot->pushScale();
-    }
-  }
-  MouseInfo->setMode(INACTIVE);
-  needrecreate = true;
-  update();
+  moveHorizontal(false);
 }
 
+
 void KstView::leftSlot() {
+  moveHorizontal(true);
+}
+
+void KstView::moveHorizontal(bool left) {
   double xmin, xmax, ymin, ymax;
   double new_xmin, new_xmax;
   unsigned int count = KST::plotList.count();
@@ -1082,8 +1129,13 @@ void KstView::leftSlot() {
   plot = KST::plotList.at(MouseInfo->getPlotNum());
   plot->getLScale(xmin, ymin, xmax, ymax);
 
-  new_xmin = xmin - (xmax - xmin)*0.1;
-  new_xmax = xmax - (xmax - xmin)*0.1;
+  if (left) {
+    new_xmin = xmin - (xmax - xmin)*0.1;
+    new_xmax = xmax - (xmax - xmin)*0.1;
+  } else {
+    new_xmin = xmin + (xmax - xmin)*0.1;
+    new_xmax = xmax + (xmax - xmin)*0.1;
+  }
 
   for (unsigned i_plot = 0; i_plot < count; i_plot++) {
     iplot = KST::plotList.at(i_plot);
@@ -1103,33 +1155,25 @@ void KstView::pauseSlot(){
 }
 
 void KstView::xLogSlot() {
-  unsigned int count = KST::plotList.count();
-  KstPlot *plot, *iplot;
-  bool xLog, yLog;
-
-  plot = KST::plotList.at(MouseInfo->getPlotNum());
-  xLog = !plot->isXLog();
-  yLog = plot->isYLog();
-
-  for (unsigned i_plot = 0; i_plot < count; i_plot++) {
-    iplot = KST::plotList.at(i_plot);
-    if (i_plot == MouseInfo->getPlotNum() || iplot->isTied()) {
-      iplot->setLog(xLog, yLog);
-    }
-  }
-  MouseInfo->setMode(INACTIVE);
-  needrecreate = true;
-  update();
+  logSlot(true);
 }
 
 void KstView::yLogSlot() {
+  logSlot(false);
+}
+
+
+void KstView::logSlot(bool x) {
   unsigned int count = KST::plotList.count();
   KstPlot *plot, *iplot;
   bool xLog, yLog;
 
   plot = KST::plotList.at(MouseInfo->getPlotNum());
-  xLog = plot->isXLog();
-  yLog = !plot->isYLog();
+  if (!plot) {
+    return;
+  }
+  xLog = x ? !plot->isXLog() : plot->isXLog();
+  yLog = x ? plot->isYLog() : !plot->isYLog();
 
   for (unsigned i_plot = 0; i_plot < count; i_plot++) {
     iplot = KST::plotList.at(i_plot);
@@ -1254,20 +1298,27 @@ void KstView::dynamicMenu(bool add, int id) {
   if (add) {
     if (!_currentPlot->Curves.contains(p)) {
       _currentPlot->addCurve(p);
+      p = 0;
+      _currentPlot = 0L;
+      ParentApp->updateDialogs();
       update();
+    } else {
+      _currentPlot = 0L;
     }
   } else {
     _currentPlot->removeCurve(p);
+    p = 0;
+    _currentPlot = 0L;
+    ParentApp->updateDialogs();
     update();
   }
-
-  _currentPlot = 0L;
 }
 
 void KstView::deleteCurrentPlot() {
   if (_currentPlot) {
     KST::plotList.remove(_currentPlot);
     _currentPlot = 0L;
+    ParentApp->updateDialogs();
     update();
   }
 }
@@ -1278,5 +1329,10 @@ void KstView::cleanupLayout() {
   update();
 }
 
+void KstView::setDataMode(bool on) {
+  _dataMode = on;
+  updateMouse();
+}
+
 #include "kstview.moc"
 // vim: ts=2 sw=2 et
