@@ -34,15 +34,16 @@
 #include "kstcolorsequence.h"
 #include "kstdatacollection.h"
 
-static const char description[] =
-I18N_NOOP("Kst: a data viewing program.");
+static const char description[] = I18N_NOOP("Kst: a data viewing program.");
 
 
 static KCmdLineOptions options[] = {
   {"F <dataFile>", I18N_NOOP("Specify data file: used to override a kst file default"), "|"},
   { "y <Y>",  I18N_NOOP("Field for Y axis (multiple allowed)"), 0 },
+  { "ye <equation>",  I18N_NOOP("Equation for Y axis (multiple allowed)"), 0 },
   { "e <E>",  I18N_NOOP("Field for Y errors (multiple allowed)"), 0 },
   { "x <X>",  I18N_NOOP("Field for X axis"),                 "INDEX"},
+  { "xe <equation>",  I18N_NOOP("Equation for X axis"),      "<none>"},
   { "p <Y>",  I18N_NOOP("Field for power spectrum (multiple allowed)"), 0},
   { "h <Y>",  I18N_NOOP("Field for histogram (multiple allowed)"), 0},
   { "r <f>",  I18N_NOOP("Sample rate for power spectrum"),      "60.0"},
@@ -106,8 +107,7 @@ void CheckForCMDErrors(KCmdLineArgs *args) {
 /*                                                              */
 /****************************************************************/
 void SetCMDOptions(KCmdLineArgs *args, struct InType &in,
-                   QCStringList &ycolList,QCStringList &psdList,
-                   QCStringList &hsList) {
+                   int n_y) {
   bool nOK;
   in.n = args->getOption("n").toInt(&nOK);
   in.f = args->getOption("f").toInt(&nOK);
@@ -123,8 +123,7 @@ void SetCMDOptions(KCmdLineArgs *args, struct InType &in,
   in.n_cols = args->getOption("m").toInt(&nOK);
   if (in.n_cols>0) {
     in.sep_plots = true;
-    in.n_plots = args->count() * (ycolList.count()+psdList.count()+
-                                  hsList.count());
+    in.n_plots = args->count() * (n_y);
   } else {
     in.n_cols = 1;
     in.n_plots = 1;
@@ -176,23 +175,46 @@ void CreatePlots(struct InType &in) {
 /*        create vectors, including name and error cheking      */
 /*                                                              */
 /****************************************************************/
-KstRVectorPtr CreateVector(QString field, KstFilePtr file, struct InType &in) {
+KstRVectorPtr CreateVector(QString field, KstDataSourcePtr file, struct InType &in) {
   KstRVectorPtr vector;
-  static int i_v=0;
+  static int i_v = 0;
 
-  vector = new KstRVector(file, field,
-                          QString("V") + QString::number(1+i_v++)
+  vector = new KstRVector(file, field, 
+			  QString("V") + QString::number(1 + i_v++)
                           + "-" + field,
                           in.f, in.n, in.skip, in.doskip, in.doave);
   if (!vector->isValid()) {
     kdError() << I18N_NOOP("Error: Invalid field: ") << vector->getField()
-         << endl << I18N_NOOP("File: ") << vector->getFilename() << endl;
+              << endl << I18N_NOOP("File: ") << vector->filename() << endl;
     exit(0); // fixme: this can cause crashes
   }
 
   return vector;
 }
 
+/****************************************************************/
+/*                                                              */
+/*        Process Equation: replace fields with vector tags     */
+/*                                                              */
+/****************************************************************/
+// void ProcessEq(QString &eq) {
+//   QString field;
+//   int i0=0, i1=0;
+//   KstVectorPtr v;
+//   int i_vector;
+
+//   while ((i0 = eq.find("[", i0))>=0) {
+//     i1 = eq.find("]", i0);
+//     if (i1>0) {
+//       field = eq.mid(i0+1, i1-i0-1);
+//       for (i_vector = 0; i_vector<KST::vectorList.count(); i_vector++);
+//       }
+//       eq.replace(i0,i1-i0+1, "[V_"+field+"]");
+//     }
+//     i0++;
+//   }
+// }
+
 /****************************************************************/
 /*                                                              */
 /*        main for kst.  mostly command line handling           */
@@ -203,7 +225,7 @@ int main(int argc, char *argv[]) {
   int i_plot;
 
   KAboutData aboutData( "kst", I18N_NOOP("Kst"),
-                        "0.92", description, KAboutData::License_GPL,
+                        "0.94", description, KAboutData::License_GPL,
                         I18N_NOOP("(c) 2000-2003 Barth Netterfield"),
                         0,
                         "http://extragear.kde.org/apps/kst.php");
@@ -223,23 +245,25 @@ int main(int argc, char *argv[]) {
   KImageIO::registerFormats();
 
   if (app.isRestored()) {
-    RESTORE(KstApp);
+    RESTORE(KstApp)
   } else {
     KstApp *kst = new KstApp;
 
     struct InType in;
     QColor color;
     QCStringList ycolList;
+    // QCStringList yEqList;
     QCStringList psdList;
     QCStringList hsList;
     QCStringList errorList;
     unsigned int i_ycol;
     QCStringList::Iterator psd;
     QCStringList::Iterator hs;
+    //QCStringList::Iterator eq_i;
     bool nOK;
 
     /* temp variables: these all get stuck into list objects */
-    KstFilePtr file;
+    KstDataSourcePtr file;
     KstRVectorPtr xvector;
     KstRVectorPtr yvector;
     KstRVectorPtr evector;
@@ -247,6 +271,7 @@ int main(int argc, char *argv[]) {
     KstPSDCurve *psdcurve;
     KstHistogramPtr hscurve;
     KstPlot *plot;
+    int n_y;
 
     /* Parse command line args */
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
@@ -258,13 +283,16 @@ int main(int argc, char *argv[]) {
 
     /* get Y axis collums */
     ycolList = args->getOptionList("y");
+    //yEqList = args->getOptionList("ye");
     psdList = args->getOptionList("p");
     hsList = args->getOptionList("h");
     errorList = args->getOptionList("e");
     // y axis or PSD specified, so the files are data files, not kst files.
-    if (ycolList.count() + psdList.count() + hsList.count() > 0) {
+    n_y = ycolList.count() + psdList.count() + hsList.count();
+    //+ yEqList.count();
+    if (n_y > 0) {
 
-      SetCMDOptions(args, in, ycolList, psdList, hsList);
+      SetCMDOptions(args, in, n_y);
 
       CreatePlots(in);
 
@@ -274,15 +302,22 @@ int main(int argc, char *argv[]) {
       /* Make the requested curves for each data file */
       for (i_curve = i_v = 0, i_file = 0; i_file < args->count(); i_file++) {
         /* Make the file */
-        file = new KstFile(args->arg(i_file));
+        file = KstDataSource::loadSource(args->arg(i_file));
 
-        if (file->numFrames()<1) { // No data in file
-          std::cerr << I18N_NOOP("Error: No data in file: ")
-	       << args->arg(i_file) << "\n";
+        if (!file) {
+          kdWarning() << I18N_NOOP("Error: No data in file: ")
+	              << args->arg(i_file) << endl;
           delete kst;
           exit(0);
         }
-        KST::fileList.append(file);
+
+	if (!file->isValid() || file->frameCount() < 1) {
+          kdWarning() << I18N_NOOP("Error: No data in file: ")
+	              << args->arg(i_file) << endl;
+          // The file might get data later!
+	}
+
+        KST::dataSourceList.append(file);
 
         if (!ycolList.isEmpty()) { // if there are some xy plots
           /* make the x axis vector */
@@ -290,7 +325,6 @@ int main(int argc, char *argv[]) {
 
           /* make the y axis vectors */
           for (i_ycol = 0; i_ycol < ycolList.count(); ++i_ycol ) {
-            /*for (ycol = ycolList.begin(); ycol != ycolList.end(); ++ycol ) */
             yvector = CreateVector(*(ycolList.at(i_ycol)), file, in);
 
             /* make the curves */
@@ -318,6 +352,13 @@ int main(int argc, char *argv[]) {
             } // end (if they are separate plots)
           } // next y col
         } // end (if there are some xy plots)
+// 	if (!yEqList.isEmpty()) {
+// 	  QString eq;
+// 	  for (eq_i = yEqList.begin(); eq_i != yEqList.end(); ++eq_i) {	  
+// 	    eq = *eq_i;
+// 	    ProcessEq(eq);
+// 	  }
+// 	}
         if (psdList.count() > 0) { // if there are some psd plots
           KstRVectorList rvl = kstObjectSubList<KstVector,KstRVector>(KST::vectorList);
           for(psd = psdList.begin(); psd != psdList.end(); ++psd ) {
